{***********************************************************}
{                                                           }
{                 Delphi 4 Runtime Library                  }
{                Microsoft LAN Manager APIs                 }
{              (svrapi.dll for Windows 95/98)               }
{                                                           }
{  Copyright (c) Sergey Kirichenko (ksv@cheerful.com), 1998 }
{  Copyright (c) Microsoft Corp., 1995                      }
{                                                           }
{***********************************************************}


unit svrapi;

{$A-}
{$WEAKPACKAGEUNIT}

interface

uses Windows, SysUtils;

const

{- Microsoft LAN Manager network error definitions -}

  NERR_Success            = 0;       (* Success *)
{ NERR_BASE is the base of error codes from network utilities,
  chosen to avoid conflict with system and redirector error codes.
  2100 is a value that has been assigned to us by system. }
  NERR_BASE       = 2100;
{***********WARNING ****************
 *The range 2750-2799 has been     *
 *allocated to the IBM LAN Server  *
 *The range 2900-2999 has been     *
 *reserved for Microsoft OEMs      *
 ***********************************}
  NERR_NetNotStarted      = (NERR_BASE+2);   (* The workstation driver is not installed. *)
  NERR_UnknownServer      = (NERR_BASE+3);   (* The server could not be located. *)
  NERR_ShareMem           = (NERR_BASE+4);   (* An internal error occurred.  The network cannot access a shared memory segment. *)
  NERR_NoNetworkResource  = (NERR_BASE+5);   (* A network resource shortage occurred . *)
  NERR_RemoteOnly         = (NERR_BASE+6);   (* This operation is not supported on workstations. *)
  NERR_DevNotRedirected   = (NERR_BASE+7);   (* The device is not connected. *)
  NERR_ServerNotStarted   = (NERR_BASE+14);  (* The Server service is not started. *)
  NERR_ItemNotFound       = (NERR_BASE+15);  (* The queue is empty. *)
  NERR_UnknownDevDir      = (NERR_BASE+16);  (* The device or directory does not exist. *)
  NERR_RedirectedPath     = (NERR_BASE+17);  (* The operation is invalid on a redirected resource. *)
  NERR_DuplicateShare     = (NERR_BASE+18);  (* The name has already been shared. *)
  NERR_NoRoom             = (NERR_BASE+19);  (* The server is currently out of the requested resource. *)
  NERR_TooManyItems       = (NERR_BASE+21);  (* Requested addition of items exceeds the maximum allowed. *)
  NERR_InvalidMaxUsers    = (NERR_BASE+22);  (* The Peer service supports only two simultaneous users. *)
  NERR_BufTooSmall        = (NERR_BASE+23);  (* The API return buffer is too small. *)
  NERR_RemoteErr          = (NERR_BASE+27);  (* A remote API error occurred.  *)
  NERR_LanmanIniError     = (NERR_BASE+31);  (* An error occurred when opening or reading the configuration file. *)
  NERR_NetworkError       = (NERR_BASE+36);  (* A general network error occurred. *)
  NERR_WkstaInconsistentState = (NERR_BASE+37); (* The Workstation service is in an inconsistent state. Restart the computer before restarting the Workstation service. *)
  NERR_WkstaNotStarted    = (NERR_BASE+38);  (* The Workstation service has not been started. *)
  NERR_BrowserNotStarted  = (NERR_BASE+39);  (* The requested information is not available. *)
  NERR_InternalError      = (NERR_BASE+40);  (* An internal Windows NT error occurred.*)
  NERR_BadTransactConfig  = (NERR_BASE+41);  (* The server is not configured for transactions. *)
  NERR_InvalidAPI         = (NERR_BASE+42);  (* The requested API is not supported on the remote server. *)
  NERR_BadEventName       = (NERR_BASE+43);  (* The event name is invalid. *)
  NERR_DupNameReboot      = (NERR_BASE+44);  (* The computer name already exists on the network. Change it and restart the computer. *)
{ Config API related Error codes from BASE+45 to BASE+49 }
  NERR_CfgCompNotFound    = (NERR_BASE+46);  (* The specified component could not be found in the configuration information. *)
  NERR_CfgParamNotFound   = (NERR_BASE+47);  (* The specified parameter could not be found in the configuration information. *)
  NERR_LineTooLong        = (NERR_BASE+49);  (* A line in the configuration file is too long. *)
{ Spooler API related Error codes from BASE+50 to BASE+79 }
  NERR_QNotFound          = (NERR_BASE+50);  (* The printer does not exist. *)
  NERR_JobNotFound        = (NERR_BASE+51);  (* The print job does not exist. *)
  NERR_DestNotFound       = (NERR_BASE+52);  (* The printer destination cannot be found. *)
  NERR_DestExists         = (NERR_BASE+53);  (* The printer destination already exists. *)
  NERR_QExists            = (NERR_BASE+54);  (* The printer queue already exists. *)
  NERR_QNoRoom            = (NERR_BASE+55);  (* No more printers can be added. *)
  NERR_JobNoRoom          = (NERR_BASE+56);  (* No more print jobs can be added.  *)
  NERR_DestNoRoom         = (NERR_BASE+57);  (* No more printer destinations can be added. *)
  NERR_DestIdle           = (NERR_BASE+58);  (* This printer destination is idle and cannot accept control operations. *)
  NERR_DestInvalidOp      = (NERR_BASE+59);  (* This printer destination request contains an invalid control function. *)
  NERR_ProcNoRespond      = (NERR_BASE+60);  (* The print processor is not responding. *)
  NERR_SpoolerNotLoaded   = (NERR_BASE+61);  (* The spooler is not running. *)
  NERR_DestInvalidState   = (NERR_BASE+62);  (* This operation cannot be performed on the print destination in its current state. *)
  NERR_QInvalidState      = (NERR_BASE+63);  (* This operation cannot be performed on the printer queue in its current state. *)
  NERR_JobInvalidState    = (NERR_BASE+64);  (* This operation cannot be performed on the print job in its current state. *)
  NERR_SpoolNoMemory      = (NERR_BASE+65);  (* A spooler memory allocation failure occurred. *)
  NERR_DriverNotFound     = (NERR_BASE+66);  (* The device driver does not exist. *)
  NERR_DataTypeInvalid    = (NERR_BASE+67);  (* The data type is not supported by the print processor. *)
  NERR_ProcNotFound       = (NERR_BASE+68);  (* The print processor is not installed. *)
{ Service API related Error codes from BASE+80 to BASE+99 }
  NERR_ServiceTableLocked  = (NERR_BASE+80);  (* The service database is locked. *)
  NERR_ServiceTableFull    = (NERR_BASE+81);  (* The service table is full. *)
  NERR_ServiceInstalled    = (NERR_BASE+82);  (* The requested service has already been started. *)
  NERR_ServiceEntryLocked  = (NERR_BASE+83);  (* The service does not respond to control actions. *)
  NERR_ServiceNotInstalled = (NERR_BASE+84); (* The service has not been started. *)
  NERR_BadServiceName      = (NERR_BASE+85);  (* The service name is invalid. *)
  NERR_ServiceCtlTimeout   = (NERR_BASE+86);  (* The service is not responding to the control function. *)
  NERR_ServiceCtlBusy      = (NERR_BASE+87);  (* The service control is busy. *)
  NERR_BadServiceProgName  = (NERR_BASE+88);  (* The configuration file contains an invalid service program name. *)
  NERR_ServiceNotCtrl      = (NERR_BASE+89);  (* The service could not be controlled in its present state. *)
  NERR_ServiceKillProc     = (NERR_BASE+90);  (* The service ended abnormally. *)
  NERR_ServiceCtlNotValid  = (NERR_BASE+91);  (* The requested pause or stop is not valid for this service. *)
  NERR_NotInDispatchTbl    = (NERR_BASE+92);  (* The service control dispatcher could not find the service name in the dispatch table. *)
  NERR_BadControlRecv      = (NERR_BASE+93);  (* The service control dispatcher pipe read failed. *)
  NERR_ServiceNotStarting  = (NERR_BASE+94);  (* A thread for the new service could not be created. *)
{ Wksta and Logon API related Error codes from BASE+100 to BASE+118}
  NERR_AlreadyLoggedOn    = (NERR_BASE+100); (* This workstation is already logged on to the local-area network. *)
  NERR_NotLoggedOn        = (NERR_BASE+101); (* The workstation is not logged on to the local-area network. *)
  NERR_BadUsername        = (NERR_BASE+102); (* The user name or group name parameter is invalid.  *)
  NERR_BadPassword        = (NERR_BASE+103); (* The password parameter is invalid. *)
  NERR_UnableToAddName_W  = (NERR_BASE+104); (* @W The logon processor did not add the message alias. *)
  NERR_UnableToAddName_F  = (NERR_BASE+105); (* The logon processor did not add the message alias. *)
  NERR_UnableToDelName_W  = (NERR_BASE+106); (* @W The logoff processor did not delete the message alias. *)
  NERR_UnableToDelName_F  = (NERR_BASE+107); (* The logoff processor did not delete the message alias. *)
  NERR_LogonsPaused        = (NERR_BASE+109); (* Network logons are paused. *)
  NERR_LogonServerConflict = (NERR_BASE+110); (* A centralized logon-server conflict occurred. *)
  NERR_LogonNoUserPath     = (NERR_BASE+111); (* The server is configured without a valid user path. *)
  NERR_LogonScriptError    = (NERR_BASE+112); (* An error occurred while loading or running the logon script. *)
  NERR_StandaloneLogon     = (NERR_BASE+114); (* The logon server was not specified.  Your computer will be logged on as STANDALONE. *)
  NERR_LogonServerNotFound = (NERR_BASE+115); (* The logon server could not be found.  *)
  NERR_LogonDomainExists   = (NERR_BASE+116); (* There is already a logon domain for this computer.  *)
  NERR_NonValidatedLogon   = (NERR_BASE+117); (* The logon server could not validate the logon. *)
{ ACF API related (access, user, group) Error codes from BASE+119 to BASE+149 }
  NERR_ACFNotFound          = (NERR_BASE+119); (* The security database could not be found. *)
  NERR_GroupNotFound        = (NERR_BASE+120); (* The group name could not be found. *)
  NERR_UserNotFound         = (NERR_BASE+121); (* The user name could not be found. *)
  NERR_ResourceNotFound     = (NERR_BASE+122); (* The resource name could not be found.  *)
  NERR_GroupExists          = (NERR_BASE+123); (* The group already exists. *)
  NERR_UserExists           = (NERR_BASE+124); (* The user account already exists. *)
  NERR_ResourceExists       = (NERR_BASE+125); (* The resource permission list already exists. *)
  NERR_NotPrimary           = (NERR_BASE+126); (* This operation is only allowed on the primary domain controller of the domain. *)
  NERR_ACFNotLoaded         = (NERR_BASE+127); (* The security database has not been started. *)
  NERR_ACFNoRoom            = (NERR_BASE+128); (* There are too many names in the user accounts database. *)
  NERR_ACFFileIOFail        = (NERR_BASE+129); (* A disk I/O failure occurred.*)
  NERR_ACFTooManyLists      = (NERR_BASE+130); (* The limit of 64 entries per resource was exceeded. *)
  NERR_UserLogon            = (NERR_BASE+131); (* Deleting a user with a session is not allowed. *)
  NERR_ACFNoParent          = (NERR_BASE+132); (* The parent directory could not be located. *)
  NERR_CanNotGrowSegment    = (NERR_BASE+133); (* Unable to add to the security database session cache segment. *)
  NERR_SpeGroupOp           = (NERR_BASE+134); (* This operation is not allowed on this special group. *)
  NERR_NotInCache           = (NERR_BASE+135); (* This user is not cached in user accounts database session cache. *)
  NERR_UserInGroup          = (NERR_BASE+136); (* The user already belongs to this group. *)
  NERR_UserNotInGroup       = (NERR_BASE+137); (* The user does not belong to this group. *)
  NERR_AccountUndefined     = (NERR_BASE+138); (* This user account is undefined. *)
  NERR_AccountExpired       = (NERR_BASE+139); (* This user account has expired. *)
  NERR_InvalidWorkstation   = (NERR_BASE+140); (* The user is not allowed to log on from this workstation. *)
  NERR_InvalidLogonHours    = (NERR_BASE+141); (* The user is not allowed to log on at this time.  *)
  NERR_PasswordExpired      = (NERR_BASE+142); (* The password of this user has expired. *)
  NERR_PasswordCantChange   = (NERR_BASE+143); (* The password of this user cannot change. *)
  NERR_PasswordHistConflict = (NERR_BASE+144); (* This password cannot be used now. *)
  NERR_PasswordTooShort     = (NERR_BASE+145); (* The password is shorter than required. *)
  NERR_PasswordTooRecent    = (NERR_BASE+146); (* The password of this user is too recent to change.  *)
  NERR_InvalidDatabase      = (NERR_BASE+147); (* The security database is corrupted. *)
  NERR_DatabaseUpToDate     = (NERR_BASE+148); (* No updates are necessary to this replicant network/local security database. *)
  NERR_SyncRequired         = (NERR_BASE+149); (* This replicant database is outdated; synchronization is required. *)
{ Use API related Error codes from BASE+150 to BASE+169 }
  NERR_UseNotFound        = (NERR_BASE+150); (* The network connection could not be found. *)
  NERR_BadAsgType         = (NERR_BASE+151); (* This asg_type is invalid. *)
  NERR_DeviceIsShared     = (NERR_BASE+152); (* This device is currently being shared. *)
{ Message Server related Error codes BASE+170 to BASE+209 }
  NERR_NoComputerName     = (NERR_BASE+170); (* The computer name could not be added as a message alias.  The name may already exist on the network. *)
  NERR_MsgAlreadyStarted  = (NERR_BASE+171); (* The Messenger service is already started. *)
  NERR_MsgInitFailed      = (NERR_BASE+172); (* The Messenger service failed to start.  *)
  NERR_NameNotFound       = (NERR_BASE+173); (* The message alias could not be found on the network. *)
  NERR_AlreadyForwarded   = (NERR_BASE+174); (* This message alias has already been forwarded. *)
  NERR_AddForwarded       = (NERR_BASE+175); (* This message alias has been added but is still forwarded. *)
  NERR_AlreadyExists      = (NERR_BASE+176); (* This message alias already exists locally. *)
  NERR_TooManyNames       = (NERR_BASE+177); (* The maximum number of added message aliases has been exceeded. *)
  NERR_DelComputerName    = (NERR_BASE+178); (* The computer name could not be deleted.*)
  NERR_LocalForward       = (NERR_BASE+179); (* Messages cannot be forwarded back to the same workstation. *)
  NERR_GrpMsgProcessor    = (NERR_BASE+180); (* An error occurred in the domain message processor. *)
  NERR_PausedRemote       = (NERR_BASE+181); (* The message was sent, but the recipient has paused the Messenger service. *)
  NERR_BadReceive         = (NERR_BASE+182); (* The message was sent but not received. *)
  NERR_NameInUse          = (NERR_BASE+183); (* The message alias is currently in use. Try again later. *)
  NERR_MsgNotStarted      = (NERR_BASE+184); (* The Messenger service has not been started. *)
  NERR_NotLocalName       = (NERR_BASE+185); (* The name is not on the local computer. *)
  NERR_NoForwardName      = (NERR_BASE+186); (* The forwarded message alias could not be found on the network. *)
  NERR_RemoteFull         = (NERR_BASE+187); (* The message alias table on the remote station is full. *)
  NERR_NameNotForwarded   = (NERR_BASE+188); (* Messages for this alias are not currently being forwarded. *)
  NERR_TruncatedBroadcast = (NERR_BASE+189); (* The broadcast message was truncated. *)
  NERR_InvalidDevice      = (NERR_BASE+194); (* This is an invalid device name. *)
  NERR_WriteFault         = (NERR_BASE+195); (* A write fault occurred. *)
  NERR_DuplicateName      = (NERR_BASE+197); (* A duplicate message alias exists on the network. *)
  NERR_DeleteLater        = (NERR_BASE+198); (* @W This message alias will be deleted later. *)
  NERR_IncompleteDel      = (NERR_BASE+199); (* The message alias was not successfully deleted from all networks. *)
  NERR_MultipleNets       = (NERR_BASE+200); (* This operation is not supported on computers with multiple networks. *)
{ Server API related Error codes BASE+210 to BASE+229 }
  NERR_NetNameNotFound        = (NERR_BASE+210); (* This shared resource does not exist.*)
  NERR_DeviceNotShared        = (NERR_BASE+211); (* This device is not shared. *)
  NERR_ClientNameNotFound     = (NERR_BASE+212); (* A session does not exist with that computer name. *)
  NERR_FileIdNotFound         = (NERR_BASE+214); (* There is not an open file with that identification number. *)
  NERR_ExecFailure            = (NERR_BASE+215); (* A failure occurred when executing a remote administration command. *)
  NERR_TmpFile                = (NERR_BASE+216); (* A failure occurred when opening a remote temporary file. *)
  NERR_TooMuchData            = (NERR_BASE+217); (* The data returned from a remote administration command has been truncated to 64K. *)
  NERR_DeviceShareConflict    = (NERR_BASE+218); (* This device cannot be shared as both a spooled and a non-spooled resource. *)
  NERR_BrowserTableIncomplete = (NERR_BASE+219);  (* The information in the list of servers may be incorrect. *)
  NERR_NotLocalDomain         = (NERR_BASE+220); (* The computer is not active in this domain. *)
  NERR_IsDfsShare             = (NERR_BASE+221); (* The share must be removed from the Distributed File System before it can be deleted. *)
{ CharDev API related Error codes BASE+230 to BASE+249 }
  NERR_DevInvalidOpCode   = (NERR_BASE+231); (* The operation is invalid for this device. *)
  NERR_DevNotFound        = (NERR_BASE+232); (* This device cannot be shared. *)
  NERR_DevNotOpen         = (NERR_BASE+233); (* This device was not open. *)
  NERR_BadQueueDevString  = (NERR_BASE+234); (* This device name list is invalid. *)
  NERR_BadQueuePriority   = (NERR_BASE+235); (* The queue priority is invalid. *)
  NERR_NoCommDevs         = (NERR_BASE+237); (* There are no shared communication devices. *)
  NERR_QueueNotFound      = (NERR_BASE+238); (* The queue you specified does not exist. *)
  NERR_BadDevString       = (NERR_BASE+240); (* This list of devices is invalid. *)
  NERR_BadDev             = (NERR_BASE+241); (* The requested device is invalid. *)
  NERR_InUseBySpooler     = (NERR_BASE+242); (* This device is already in use by the spooler. *)
  NERR_CommDevInUse       = (NERR_BASE+243); (* This device is already in use as a communication device. *)
{ NetICanonicalize and NetIType and NetIMakeLMFileName
  NetIListCanon and NetINameCheck
  Error codes BASE+250 to BASE+269 }
  NERR_InvalidComputer   = (NERR_BASE+251); (* This computer name is invalid. *)
  NERR_MaxLenExceeded    = (NERR_BASE+254); (* The string and prefix specified are too long. *)
  NERR_BadComponent      = (NERR_BASE+256); (* This path component is invalid. *)
  NERR_CantType          = (NERR_BASE+257); (* Could not determine the type of input. *)
  NERR_TooManyEntries    = (NERR_BASE+262); (* The buffer for types is not big enough. *)
{ NetProfile Error codes BASE+270 to BASE+276 }
  NERR_ProfileFileTooBig  = (NERR_BASE+270); (* Profile files cannot exceed 64K. *)
  NERR_ProfileOffset      = (NERR_BASE+271); (* The start offset is out of range. *)
  NERR_ProfileCleanup     = (NERR_BASE+272); (* The system cannot delete current connections to network resources. *)
  NERR_ProfileUnknownCmd  = (NERR_BASE+273); (* The system was unable to parse the command line in this file.*)
  NERR_ProfileLoadErr     = (NERR_BASE+274); (* An error occurred while loading the profile file. *)
  NERR_ProfileSaveErr     = (NERR_BASE+275); (* @W Errors occurred while saving the profile file.  The profile was partially saved. *)
{ NetAudit and NetErrorLog Error codes BASE+277 to BASE+279 }
  NERR_LogOverflow           = (NERR_BASE+277);      (* Log file %1 is full. *)
  NERR_LogFileChanged        = (NERR_BASE+278);      (* This log file has changed between reads. *)
  NERR_LogFileCorrupt        = (NERR_BASE+279);      (* Log file %1 is corrupt. *)
{ NetRemote Error codes BASE+280 to BASE+299 }
  NERR_SourceIsDir        = (NERR_BASE+280); (* The source path cannot be a directory. *)
  NERR_BadSource          = (NERR_BASE+281); (* The source path is illegal. *)
  NERR_BadDest            = (NERR_BASE+282); (* The destination path is illegal. *)
  NERR_DifferentServers   = (NERR_BASE+283); (* The source and destination paths are on different servers. *)
  NERR_RunSrvPaused       = (NERR_BASE+285); (* The Run server you requested is paused. *)
  NERR_ErrCommRunSrv      = (NERR_BASE+289); (* An error occurred when communicating with a Run server. *)
  NERR_ErrorExecingGhost  = (NERR_BASE+291); (* An error occurred when starting a background process. *)
  NERR_ShareNotFound      = (NERR_BASE+292); (* The shared resource you are connected to could not be found.*)
{ NetWksta.sys (redir); returned error codes. NERR_BASE + (300-329) }
  NERR_InvalidLana        = (NERR_BASE+300); (* The LAN adapter number is invalid.  *)
  NERR_OpenFiles          = (NERR_BASE+301); (* There are open files on the connection.    *)
  NERR_ActiveConns        = (NERR_BASE+302); (* Active connections still exist. *)
  NERR_BadPasswordCore    = (NERR_BASE+303); (* This share name or password is invalid. *)
  NERR_DevInUse           = (NERR_BASE+304); (* The device is being accessed by an active process. *)
  NERR_LocalDrive         = (NERR_BASE+305); (* The drive letter is in use locally. *)
{ Alert error codes. NERR_BASE + (330-339) }
  NERR_AlertExists        = (NERR_BASE+330); (* The specified client is already registered for the specified event. *)
  NERR_TooManyAlerts      = (NERR_BASE+331); (* The alert table is full. *)
  NERR_NoSuchAlert        = (NERR_BASE+332); (* An invalid or nonexistent alert name was raised. *)
  NERR_BadRecipient       = (NERR_BASE+333); (* The alert recipient is invalid.*)
  NERR_AcctLimitExceeded  = (NERR_BASE+334); (* A user's session with this server has been deleted
                                                 * because the user's logon hours are no longer valid. *)
{ Additional Error and Audit log codes. NERR_BASE +(340-343) }
  NERR_InvalidLogSeek     = (NERR_BASE+340); (* The log file does not contain the requested record number. *)
{  Additional UAS and NETLOGON codes NERR_BASE +(350-359) }
  NERR_BadUasConfig       = (NERR_BASE+350); (* The user accounts database is not configured correctly. *)
  NERR_InvalidUASOp       = (NERR_BASE+351); (* This operation is not permitted when the Netlogon service is running. *)
  NERR_LastAdmin          = (NERR_BASE+352); (* This operation is not allowed on the last administrative account. *)
  NERR_DCNotFound         = (NERR_BASE+353); (* Could not find domain controller for this domain. *)
  NERR_LogonTrackingError = (NERR_BASE+354); (* Could not set logon information for this user. *)
  NERR_NetlogonNotStarted = (NERR_BASE+355); (* The Netlogon service has not been started. *)
  NERR_CanNotGrowUASFile  = (NERR_BASE+356); (* Unable to add to the user accounts database. *)
  NERR_TimeDiffAtDC       = (NERR_BASE+357); (* This server's clock is not synchronized with the primary domain controller's clock. *)
  NERR_PasswordMismatch   = (NERR_BASE+358); (* A password mismatch has been detected. *)
{ Server Integration error codes. NERR_BASE +(360-369) }
  NERR_NoSuchServer       = (NERR_BASE+360); (* The server identification does not specify a valid server. *)
  NERR_NoSuchSession      = (NERR_BASE+361); (* The session identification does not specify a valid session. *)
  NERR_NoSuchConnection   = (NERR_BASE+362); (* The connection identification does not specify a valid connection. *)
  NERR_TooManyServers     = (NERR_BASE+363); (* There is no space for another entry in the table of available servers. *)
  NERR_TooManySessions    = (NERR_BASE+364); (* The server has reached the maximum number of sessions it supports. *)
  NERR_TooManyConnections = (NERR_BASE+365); (* The server has reached the maximum number of connections it supports. *)
  NERR_TooManyFiles       = (NERR_BASE+366); (* The server cannot open more files because it has reached its maximum number. *)
  NERR_NoAlternateServers = (NERR_BASE+367); (* There are no alternate servers registered on this server. *)
  NERR_TryDownLevel       = (NERR_BASE+370); (* Try down-level (remote admin protocol); version of API instead. *)
{ UPS error codes. NERR_BASE + (380-384) }
  NERR_UPSDriverNotStarted    = (NERR_BASE+380); (* The UPS driver could not be accessed by the UPS service. *)
  NERR_UPSInvalidConfig       = (NERR_BASE+381); (* The UPS service is not configured correctly. *)
  NERR_UPSInvalidCommPort     = (NERR_BASE+382); (* The UPS service could not access the specified Comm Port. *)
  NERR_UPSSignalAsserted      = (NERR_BASE+383); (* The UPS indicated a line fail or low battery situation. Service not started. *)
  NERR_UPSShutdownFailed      = (NERR_BASE+384); (* The UPS service failed to perform a system shut down. *)
{ Remoteboot error codes.
   NERR_BASE + (400-419)
   Error codes 400 - 405 are used by RPLBOOT.SYS.
   Error codes 403, 407 - 416 are used by RPLLOADR.COM,
   Error code 417 is the alerter message of REMOTEBOOT (RPLSERVR.EXE).
   Error code 418 is for when REMOTEBOOT can't start
   Error code 419 is for a disallowed 2nd rpl connection }
  NERR_BadDosRetCode      = (NERR_BASE+400); (* The program below returned an MS-DOS error code:*)
  NERR_ProgNeedsExtraMem  = (NERR_BASE+401); (* The program below needs more memory:*)
  NERR_BadDosFunction     = (NERR_BASE+402); (* The program below called an unsupported MS-DOS function:*)
  NERR_RemoteBootFailed   = (NERR_BASE+403); (* The workstation failed to boot.*)
  NERR_BadFileCheckSum    = (NERR_BASE+404); (* The file below is corrupt.*)
  NERR_NoRplBootSystem    = (NERR_BASE+405); (* No loader is specified in the boot-block definition file.*)
  NERR_RplLoadrNetBiosErr = (NERR_BASE+406); (* NetBIOS returned an error: The NCB and SMB are dumped above.*)
  NERR_RplLoadrDiskErr    = (NERR_BASE+407); (* A disk I/O error occurred.*)
  NERR_ImageParamErr      = (NERR_BASE+408); (* Image parameter substitution failed.*)
  NERR_TooManyImageParams = (NERR_BASE+409); (* Too many image parameters cross disk sector boundaries.*)
  NERR_NonDosFloppyUsed   = (NERR_BASE+410); (* The image was not generated from an MS-DOS diskette formatted with /S.*)
  NERR_RplBootRestart     = (NERR_BASE+411); (* Remote boot will be restarted later.*)
  NERR_RplSrvrCallFailed  = (NERR_BASE+412); (* The call to the Remoteboot server failed.*)
  NERR_CantConnectRplSrvr = (NERR_BASE+413); (* Cannot connect to the Remoteboot server.*)
  NERR_CantOpenImageFile  = (NERR_BASE+414); (* Cannot open image file on the Remoteboot server.*)
  NERR_CallingRplSrvr     = (NERR_BASE+415); (* Connecting to the Remoteboot server...*)
  NERR_StartingRplBoot    = (NERR_BASE+416); (* Connecting to the Remoteboot server...*)
  NERR_RplBootServiceTerm = (NERR_BASE+417); (* Remote boot service was stopped; check the error log for the cause of the problem.*)
  NERR_RplBootStartFailed = (NERR_BASE+418); (* Remote boot startup failed; check the error log for the cause of the problem.*)
  NERR_RPL_CONNECTED      = (NERR_BASE+419); (* A second connection to a Remoteboot resource is not allowed.*)
{ FTADMIN API error codes NERR_BASE + (425-434) }
(* Currently not used in NT *)
{ Browser service API error codes NERR_BASE + (450-475) }
  NERR_BrowserConfiguredToNotRun     = (NERR_BASE+450); (* The browser service was configured with MaintainServerList=No. *)
{ Additional Remoteboot error codes. NERR_BASE + (510-550) }
  NERR_RplNoAdaptersStarted          = (NERR_BASE+510); (*Service failed to start since none of the network adapters started with this service.*)
  NERR_RplBadRegistry                = (NERR_BASE+511); (*Service failed to start due to bad startup information in the registry.*)
  NERR_RplBadDatabase                = (NERR_BASE+512); (*Service failed to start because its database is absent or corrupt.*)
  NERR_RplRplfilesShare              = (NERR_BASE+513); (*Service failed to start because RPLFILES share is absent.*)
  NERR_RplNotRplServer               = (NERR_BASE+514); (*Service failed to start because RPLUSER group is absent.*)
  NERR_RplCannotEnum                 = (NERR_BASE+515); (*Cannot enumerate service records.*)
  NERR_RplWkstaInfoCorrupted         = (NERR_BASE+516); (*Workstation record information has been corrupted.*)
  NERR_RplWkstaNotFound              = (NERR_BASE+517); (*Workstation record was not found.*)
  NERR_RplWkstaNameUnavailable       = (NERR_BASE+518); (*Workstation name is in use by some other workstation.*)
  NERR_RplProfileInfoCorrupted       = (NERR_BASE+519); (*Profile record information has been corrupted.*)
  NERR_RplProfileNotFound            = (NERR_BASE+520); (*Profile record was not found.*)
  NERR_RplProfileNameUnavailable     = (NERR_BASE+521); (*Profile name is in use by some other profile.*)
  NERR_RplProfileNotEmpty            = (NERR_BASE+522); (*There are workstations using this profile.*)
  NERR_RplConfigInfoCorrupted        = (NERR_BASE+523); (*Configuration record information has been corrupted.*)
  NERR_RplConfigNotFound             = (NERR_BASE+524); (*Configuration record was not found.*)
  NERR_RplAdapterInfoCorrupted       = (NERR_BASE+525); (*Adapter id record information has been corrupted.*)
  NERR_RplInternal                   = (NERR_BASE+526); (*An internal service error has occured.*)
  NERR_RplVendorInfoCorrupted        = (NERR_BASE+527); (*Vendor id record information has been corrupted.*)
  NERR_RplBootInfoCorrupted          = (NERR_BASE+528); (*Boot block record information has been corrupted.*)
  NERR_RplWkstaNeedsUserAcct         = (NERR_BASE+529); (*The user account for this workstation record is missing.*)
  NERR_RplNeedsRPLUSERAcct           = (NERR_BASE+530); (*The RPLUSER local group could not be found.*)
  NERR_RplBootNotFound               = (NERR_BASE+531); (*Boot block record was not found.*)
  NERR_RplIncompatibleProfile        = (NERR_BASE+532); (*Chosen profile is incompatible with this workstation.*)
  NERR_RplAdapterNameUnavailable     = (NERR_BASE+533); (*Chosen network adapter id is in use by some other workstation.*)
  NERR_RplConfigNotEmpty             = (NERR_BASE+534); (*There are profiles using this configuration.*)
  NERR_RplBootInUse                  = (NERR_BASE+535); (*There are workstations, profiles or configurations using this boot block.*)
  NERR_RplBackupDatabase             = (NERR_BASE+536); (*Service failed to backup remoteboot database.*)
  NERR_RplAdapterNotFound            = (NERR_BASE+537); (*Adapter record was not found.*)
  NERR_RplVendorNotFound             = (NERR_BASE+538); (*Vendor record was not found.*)
  NERR_RplVendorNameUnavailable      = (NERR_BASE+539); (*Vendor name is in use by some other vendor record.*)
  NERR_RplBootNameUnavailable        = (NERR_BASE+540); (*(boot name, vendor id); is in use by some other boot block record.*)
  NERR_RplConfigNameUnavailable      = (NERR_BASE+541); (*Configuration name is in use by some other configuration.*)
{ Dfs API error codes. NERR_BASE + (560-590) }
  NERR_DfsInternalCorruption         = (NERR_BASE+560); (*The internal database maintained by the Dfs service is corrupt*)
  NERR_DfsVolumeDataCorrupt          = (NERR_BASE+561); (*One of the records in the internal Dfs database is corrupt*)
  NERR_DfsNoSuchVolume               = (NERR_BASE+562); (*There is no volume whose entry path matches the input Entry Path*)
  NERR_DfsVolumeAlreadyExists        = (NERR_BASE+563); (*A volume with the given name already exists*)
  NERR_DfsAlreadyShared              = (NERR_BASE+564); (*The server share specified is already shared in the Dfs*)
  NERR_DfsNoSuchShare                = (NERR_BASE+565); (*The indicated server share does not support the indicated Dfs volume*)
  NERR_DfsNotALeafVolume             = (NERR_BASE+566); (*The operation is not valid on a non-leaf volume*)
  NERR_DfsLeafVolume                 = (NERR_BASE+567); (*The operation is not valid on a leaf volume*)
  NERR_DfsVolumeHasMultipleServers   = (NERR_BASE+568); (*The operation is ambiguous because the volume has multiple servers*)
  NERR_DfsCantCreateJunctionPoint    = (NERR_BASE+569); (*Unable to create a junction point*)
  NERR_DfsServerNotDfsAware          = (NERR_BASE+570); (*The server is not Dfs Aware*)
  NERR_DfsBadRenamePath              = (NERR_BASE+571); (*The specified rename target path is invalid*)
  NERR_DfsVolumeIsOffline            = (NERR_BASE+572); (*The specified Dfs volume is offline*)
  NERR_DfsNoSuchServer               = (NERR_BASE+573); (*The specified server is not a server for this volume*)
  NERR_DfsCyclicalName               = (NERR_BASE+574); (*A cycle in the Dfs name was detected*)
  NERR_DfsNotSupportedInServerDfs    = (NERR_BASE+575); (*The operation is not supported on a server-based Dfs*)
  NERR_DfsInternalError              = (NERR_BASE+590); (*Dfs internal error*)

  MAX_NERR                = (NERR_BASE+899); (* This is the last error in NERR range. *)

{- Microsoft LAN Manager API constants definitions -}

type
  API_FUNCTION            = dword;
  NET_API_STATUS          = dword;
  API_RET_TYPE            = NET_API_STATUS;      // Old value: do not use

{ String Lengths for various LanMan names }
const
  CNLEN       = MAX_COMPUTERNAME_LENGTH;   // Computer name length
  LM20_CNLEN  = 15;                  // LM 2.0 Computer name length
  DNLEN       = CNLEN;               // Maximum domain name length
  LM20_DNLEN  = LM20_CNLEN;          // LM 2.0 Maximum domain name length
  UNCLEN      = (CNLEN+2);           // UNC computer name length
  LM20_UNCLEN = (LM20_CNLEN+2);      // LM 2.0 UNC computer name length
  NNLEN       = 80;                  // Net name length (share name)
  LM20_NNLEN  = 12;                  // LM 2.0 Net name length
  RMLEN       = (UNCLEN+1+NNLEN);    // Max remote name length
  LM20_RMLEN  = (LM20_UNCLEN+1+LM20_NNLEN); // LM 2.0 Max remote name length
  SNLEN        = 80;                  // Service name length
  LM20_SNLEN   = 15;                  // LM 2.0 Service name length
  STXTLEN      = 256;                 // Service text length
  LM20_STXTLEN = 63;                  // LM 2.0 Service text length
  PATHLEN      = 256;                 // Max. path (not including drive name)
  LM20_PATHLEN = 256;                 // LM 2.0 Max. path
  DEVLEN       = 80;                  // Device name length
  LM20_DEVLEN  = 8;                   // LM 2.0 Device name length
  EVLEN        = 16;                  // Event name length
{ User, Group and Password lengths }
  UNLEN       = 256;                 // Maximum user name length
  LM20_UNLEN  = 20;                  // LM 2.0 Maximum user name length
  GNLEN       = UNLEN;               // Group name
  LM20_GNLEN  = LM20_UNLEN;          // LM 2.0 Group name
  PWLEN       = 256;                 // Maximum password length
  LM20_PWLEN  = 14;                  // LM 2.0 Maximum password length
  SHPWLEN     = 8;                   // Share password length (bytes)
  CLTYPE_LEN  = 12;                  // Length of client type string
  MAXCOMMENTSZ      = 256;           // Multipurpose comment length
  LM20_MAXCOMMENTSZ = 48;            // LM 2.0 Multipurpose comment length
  QNLEN       = NNLEN;               // Queue name maximum length
  LM20_QNLEN  = LM20_NNLEN;          // LM 2.0 Queue name maximum length
{ The ALERTSZ and MAXDEVENTRIES defines have not yet been NT'ized.
  Whoever ports these components should change these values appropriately.}
  ALERTSZ       = 128;                 // size of alert string in server
  MAXDEVENTRIES = (sizeof(integer)*8); // Max number of device entries
                                       // We use int bitmap to represent
  NETBIOS_NAME_LEN  = 16;              // NetBIOS net name (bytes)
{ Value to be used with APIs which have a "preferred maximum length"
  parameter.  This value indicates that the API should just allocate
  "as much as it takes."}
  MAX_PREFERRED_LENGTH    = DWORD(-1);
{ Constants used with encryption }
  CRYPT_KEY_LEN           = 7;
  CRYPT_TXT_LEN           = 8;
  ENCRYPTED_PWLEN         = 16;
  SESSION_PWLEN           = 24;
  SESSION_CRYPT_KLEN      = 21;

{ Value to be used with SetInfo calls to allow setting of all
  settable parameters (parmnum zero option) }
{$ifndef PARMNUM_ALL}
  PARMNUM_ALL             = 0;
{$endif}

  PARM_ERROR_UNKNOWN      = DWORD(-1);
  PARM_ERROR_NONE         = 0;
  PARMNUM_BASE_INFOLEVEL  = 1000;

{ Message File Names }

  MESSAGE_FILENAME        = 'NETMSG';
  OS2MSG_FILENAME         = 'BASE';
  HELP_MSG_FILENAME       = 'NETH';

{ The backup message file named here is a duplicate of net.msg. It
  is not shipped with the product, but is used at buildtime to
  msgbind certain messages to netapi.dll and some of the services.
  This allows for OEMs to modify the message text in net.msg and
  have those changes show up. Only in case there is an error in
  retrieving the messages from net.msg do we then get the bound
  messages out of bak.msg (really out of the message segment).}

  BACKUP_MSG_FILENAME     = 'BAK.MSG';

{ The platform ID indicates the levels to use for platform-specific
  information. }
  PLATFORM_ID_DOS = 300;
  PLATFORM_ID_OS2 = 400;
  PLATFORM_ID_NT  = 500;
  PLATFORM_ID_OSF = 600;
  PLATFORM_ID_VMS = 700;

  MIN_LANMAN_MESSAGE_ID  = NERR_BASE;
  MAX_LANMAN_MESSAGE_ID  = 5799;


{NOW: information about the NetAccess, NetConnection, NetFile,
  NetServer, NetSession, NetShare and NetSecurity APIs.                                               *
 WARNING:
  The APIs documented herein are not guaranteed to be supported
  in future versions of Windows. Their primary purpose is to
  administer Win95 peer servers. }

{ NOTE:  Lengths of ASCIIZ strings are given as the maximum
  strlen() value.  This does not include space for the
  terminating 0-byte.  When allocating space for such an item,
  use the form:
    char username[LM20_UNLEN+1];
  An exception to this is the PATHLEN manifest, which does
  include space for the terminating 0-byte.
  User names, computer names and share names should be
  upper-cased by the caller and drawn from the ANSI
  character set.}

{- Access Class -}
{****************************************************************
 * Function prototypes - ACCESS
 * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Requires User level security to be enabled
 *
 *	Peer Server Support:
 *      Remote support of these APIs on NWSERVER is limited as
 *      described below:
 *
 *	 NetAccessAdd -
 *		local and remote VSERVER - level 2
 *              remote NWSERVER -          level 2
 *	NetAccessCheck - local only
 *      NetAccessDel -
 *              local, remote NWSERVER and remote VSERVER
 *      NetAccessEnum -
 *              sLevel 0 on remote NWSERVER (fRecursive = 1),
 *              slevel 0, 1, 2 on local and remote VSERVER
 *		NetAccessGetInfo -
 *                all sLevels on local and remote VSERVER,
 *      	  sLevel 0, 12 on remote NWSERVER
 *      NetAccessSetInfo -
 *              sLevel 1, 12 on local and remote VSERVER,
 *              sLevel 12 on remote NWSERVER
 *              parmnum = PARMNUM_ALL only
 *      NetAccessGetUserPerms - local and remote VSERVER only
 ****************************************************************}

  function NetAccessAdd(const pszServer:PChar;sLevel: short; pbBuffer: PChar;cbBuffer: Word): DWORD; stdcall;
  function NetAccessCheck(pszReserved,pszUserName,pszResource: PChar;usOperation: Word;var pusResult: Word ): DWORD; stdcall;
  function NetAccessDel(const pszServer: PChar;pszResource: PChar): DWORD; stdcall;
  function NetAccessEnum(const pszServer: PChar;pszBasePath: PChar;fsRecursive,sLevel: short;pbBuffer: PChar;cbBuffer: Word;var pcEntriesRead, pcTotalAvail: Word): DWORD; stdcall;
  function NetAccessGetInfo(const pszServer: PChar;pszResource: PChar;sLevel: short;pbBuffer: PChar;cbBuffer: Word;var pcbTotalAvail: Word): DWORD; stdcall;
  function NetAccessSetInfo(const pszServer: PChar;pszResource: PChar;sLevel: short;pbBuffer: PChar;cbBuffer: Word;sParmNum: short ): DWORD; stdcall;
  function NetAccessGetUserPerms(pszServer,pszUgName,pszResource: PChar;var pusPerms: Word): DWORD; stdcall;

{ Data structure templates - ACCESS }
type
  access_list = packed record
    acl_ugname: array [0..LM20_UNLEN] of char;
    acl_ugname_pad_1: char;
    acl_access: short;
  end;      (* access_list *)

  access_list_2 = packed record
    acl2_ugname: pchar;
    acl2_access: word;
  end;      (* access_list_2 *)

  access_list_12 = packed record
    acl12_ugname: pchar;
    acl12_access: word;
  end;      (* access_list_12 *)

  access_info_0 = packed record
    acc0_resource_name: pchar;
  end;      (* access_info_0 *)

  access_info_1 = packed record
    acc1_resource_name: pchar;
    acc1_attr: short;
    acc1_count: short;
  end;      (* access_info_1 *)

  access_info_2 = packed record
    acc2_resource_name: pchar;
    acc2_attr: short;
    acc2_count: short;
  end;      (* access_info_2 *)

  access_info_10 = packed record
    acc10_resource_name: pchar;
  end;      (* access_info_10 *)

  access_info_12 = packed record
    acc12_resource_name: pchar;
    acc12_attr: short;
    acc12_count: short;
  end;      (* access_info_12 *)


{- Special values and constants - ACCESS -}

const
{ Maximum number of permission entries for each resource.}
  MAXPERMENTRIES        = 64;

{ Bit values for the access permissions.  ACCESS_ALL is a handy
  way to specify maximum permissions.  These are used in
  acl_access field of access_list structures.}
  ACCESS_NONE           = 0;
  ACCESS_READ           = $1;
  ACCESS_WRITE          = $2;
  ACCESS_CREATE         = $4;
  ACCESS_EXEC           = $8;
  ACCESS_DELETE         = $10;
  ACCESS_ATRIB          = $20;
  ACCESS_PERM           = $40;
  ACCESS_FINDFIRST      = $80;
  ACCESS_GROUP          = $8000;
  ACCESS_ALL            = (ACCESS_READ or ACCESS_WRITE or ACCESS_CREATE or ACCESS_EXEC or ACCESS_DELETE or ACCESS_ATRIB or ACCESS_PERM or ACCESS_FINDFIRST);
{ Bit values for the acc1_attr field of the access_info_1 structure.
  Only one bit is currently defined.}
  ACCESS_AUDIT          = $1;
{ Parmnum value for NetAccessSetInfo.}
  ACCESS_ATTR_PARMNUM   = 2;
{ ACCESS_LETTERS defines a letter for each bit position in
 the acl_access field of struct access_list.  Note that some
 bits have a corresponding letter of ' ' (space).}
  ACCESS_LETTERS        = 'RWCXDAP         ';

{- Share Class -}
{****************************************************************
 *  Function prototypes - SHARE
 *  ~~~~~~~~~~~~~~~~~~~~~~~~~~~
 *  Peer Server Support
 *    NetShareAdd() - sLevel 50 on VSERVER and NWSERVER
 *    NetShareDel() - VSERVER and NWSERVER
 *    NetShareEnum() - sLevel 1,50 on VSERVER; 50 on NWSERVER
 *    NetShareGetInfo() - sLevel 50 on VSERVER, NWSERVER
 *    NetShareSetInfo() - sLevel 50, sParmNum PARMNUM_ALL
 *			  on VSERVER, NWSERVER
 ****************************************************************}

(*	NetShareAdd - add a new share to the server tables
 *
 *	NetShareAdd( servername, level, buf, buflen )
 *
 *	ENTRY:	servername - asciz string containing name of server
 *                       or NULL if local
 *		level- Must be 50 for Win95 peer servers.
 *		buf - far ptr to struct share_info
 *		buflen - unsigned int length of buffer
 *
 *	EXIT:	0 = success
 *		ERROR_INVALID_LEVEL
 *      ERROR_BAD_NETPATH
 *		ERROR_INVALID_PARAMETER
 *		NERR_UnknownDevDir
 *		NERR_ShareExists
 *		NERR_UnknownServer
 *		NERR_ServerNotStarted
 *		NERR_RedirectedPath
 *		NERR_DuplicateShare
 *		NERR_BufTooSmall
 *		ERROR_NOT_ENOUGH_MEMORY
 *
 *)
function NetShareAdd(const pszServer: PChar;sLevel: short;const pbBuffer: PChar;cbBuffer: Word): DWORD; stdcall;

(*	NetShareDel (Admin only)
 *
 *	API_FUNCTION NetShareDel( servername, netname, reserved )
 *
 *	ENTRY
 *
 *	PChar  servername;     asciz remote srv name, NULL if local
 *	PChar  netname;        asciz network name of share being deleted
 *	Word reserved;    MBZ
 *
 *	EXIT
 *
 *	0 = success
 *	NERR_NetNotStarted
 *  ERROR_BAD_NETPATH
 *	NERR_ServerNotStarted
 *	NERR_NetNameNotFound
 *	ERROR_INVALID_PARAMETER
 *
 *
 *	Note:  Deleting a share will also delete any existing connections
 *		to the shared resource, and close open files within the
 *		connections.
 *)
function NetShareDel(const pszServer, pszNetName: PChar;usReserved: Word): DWORD; stdcall;

(* 2.1  NetShareEnum
 *
 * API_FUNCTION
 * NetShareEnum( servername, level, buf, buflen, entriesread, totalentries )
 * PChar          servername;     asciz remote server name or NULL if local
 * short               sLevel;         level of detail requested; 1 or 50
 * PChar          pbBuffer;       buffer to return entries in
 * Word      cbBuffer;       size of buffer on call
 * Word varpcEntriesRead;  # of entries supplied on return
 * Word varpcTotalAvail ;  total # of entries available
 *
 * Supply information about existing shares at specified level.
 *
 * Buffer contents on response (format for a single entry):
 *     Level 1 contains a "struct share_info_1".
 *     Level 50 contains a "struct share_info_50".
 *
 * Returns 0 if successful.  Possible error returns:
 *  ERROR_INVALID_LEVEL
 *  ERROR_BAD_NETPATH
 *  NERR_NetNotStarted
 *  NERR_ServerNotStarted
 *  ERROR_MORE_DATA
 *)
function NetShareEnum(const pszServer: PChar;sLevel: short;pbBuffer: PChar;cbBuffer: Word;var pcEntriesRead,pcTotalAvail: Word): DWORD; stdcall;

(* 2.2  NetShareGetInfo
 *
 * Purpose: Read complete information about a single outstanding share.
 *
 * API_FUNCTION
 * NetShareGetInfo( servername, netname, level, buf, buflen, totalavail )
 * PChar          servername;     asciz remote server name or NULL if local
 * PChar          netname;        asciz network name of share being queried
 * short               level;          level of info requested (50 for Win95 peer servers)
 * PChar          buf;            for returned entry
 * Word      buflen;         size of buffer
 * Word vartotalavail;     total size needed for buffer
 *
 * Buffer contents on response:
 *     Level 50 contains a "struct share_info_50".
 *
 * Returns 0 if successful.  Possible error returns:
 *  ERROR_INVALID_LEVEL
 *  ERROR_INVALID_PARAMETER
 *  ERROR_BAD_NETPATH
 *  NERR_NetNotStarted
 *  NERR_ServerNotStarted
 *  NERR_NetNameNotFound
 *  NERR_MoreData
 *  NERR_BufTooSmall
 *)
function NetShareGetInfo(const pszServer,pszNetName: PChar;sLevel: short; pbBuffer: PChar;cbBuffer: Word;var pcbTotalAvail: Word): DWORD; stdcall;

(*	NetShareSetInfo (Admin only)
 *
 *	API_FUNCTION NetShareSetInfo( servername,
 *					netname,
 *					level,
 *					buf,
 *					buflen,
 *					parmnum )
 *
 *	ENTRY
 *
 *	servername;     asciz remote srv name, NULL if local
 *	netname;        asciz network name of share being set
 *	level;		level of info provided (50 for Win95 peer servers)
 *	buf;            contents described below
 *	buflen;         size of buffer
 *	parmnum;        must be PARMNUM_ALL for Win95 peer servers
 *
 *	Buffer contents on call if parmnum is zero:
 *   	    Level 50 contains a "struct share_info_50".
 *
 *	Settable fields are:
 *          shi_remark
 *          shi_passwd
 *
 *	EXIT
 *
 *	0 = success
 *	NERR_NetNotStarted
 *	NERR_ServerNotStarted
 *	NERR_NetNameNotFound
 *	ERROR_INVALID_LEVEL
 * 	NERR_BufTooSmall
 *	NERR_RemoteErr
 *	ERROR_MORE_DATA
 *	ERROR_INVALID_PARAMETER
 *)
function NetShareSetInfo(const pszServer,pszNetName: PChar;sLevel: short;const pbBuffer: PChar;cbBuffer: Word;sParmNum: short ): DWORD; stdcall;


{ Data structure templates - SHARE }

type
  Pshare_info_0 = ^Tshare_info_0;
  _share_info_0 = packed record
    shi0_netname: array [0..LM20_NNLEN] of Char;
  end;  (* _share_info_0 *)
  Tshare_info_0 = _share_info_0;

  Pshare_info_1 = ^Tshare_info_1;
  _share_info_1 = packed record
    shi1_netname: array [0..LM20_NNLEN] of char;
    shi1_pad1: char;
    shi1_type: Word;
    shi1_remark: PChar;
  end;  (* _share_info_1 *)
  Tshare_info_1 = _share_info_1;

  Pshare_info_2 = ^Tshare_info_2;
  _share_info_2 = packed record
    shi2_netname: array [0..LM20_NNLEN] of Char;
    shi2_pad1: char;
    shi2_type: Word;
    shi2_remark: PChar;
    shi2_permissions: Word;
    shi2_max_uses: Word;
    shi2_current_uses: Word;
    shi2_path: PChar;
    shi2_passwd: array [0..SHPWLEN] of Char;
    shi2_pad2: char;
  end;  (* _share_info_2 *)
  Tshare_info_2 = _share_info_2;

  Pshare_info_50 = ^Tshare_info_50;
  _share_info_50 = packed record
    shi50_netname: array [0..LM20_NNLEN] of Char;    (* share name *)
    shi50_type: Byte;                                (* see below *)
    shi50_flags: Word;                               (* see below *)
    shi50_remark: PChar;                             (* ANSI comment string *)
    shi50_path: PChar;                               (* shared resource *)
    shi50_rw_password: array [0..SHPWLEN] of Char;   (* read-write password (share-level security) *)
    shi50_ro_password: array [0..SHPWLEN] of Char;   (* read-only password (share-level security) *)
  end;	(* _share_info_50 *)
  Tshare_info_50 = _share_info_50;


{ Special values and constants - SHARE }

{ Field values for shi50_flags; }

{ These flags are relevant for share-level security on VSERVER
  When operating with user-level security, use SHI50F_FULL - the actual
  access rights are determined by the NetAccess APIs.}
const
  SHI50F_RDONLY		= $0001;
  SHI50F_FULL		= $0002;
  SHI50F_DEPENDSON	= (SHI50F_RDONLY or SHI50F_FULL);
  SHI50F_ACCESSMASK	= (SHI50F_RDONLY or SHI50F_FULL);

{ The share is restored on system startup }
  SHI50F_PERSIST	= $0100;
{ The share is not normally visible }
  SHI50F_SYSTEM		= $0200;


{ Values for parmnum parameter to NetShareSetInfo. }
  SHI_REMARK_PARMNUM		        = 4;
  SHI_PERMISSIONS_PARMNUM		= 5;
  SHI_MAX_USES_PARMNUM		        = 6;
  SHI_PASSWD_PARMNUM		        = 9;
  SHI1_NUM_ELEMENTS		        = 4;
  SHI2_NUM_ELEMENTS		        = 10;

{- Share types -}

{ STYPE_DISKTREE and STYPE_PRINTQ are recognized on peer servers }

  STYPE_DISKTREE 			= 0;       (* disk share *)
  STYPE_PRINTQ   			= 1;       (* printer share *)
  STYPE_DEVICE   			= 2;
  STYPE_IPC      			= 3;

  SHI_USES_UNLIMITED		        = -1;



{- Session Class -}

{****************************************************************
 *  Function prototypes - SESSION
 *  ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 *  Peer Server Support
 *    NetSessionDel() - NWSERVER and VSERVER
 *    NetSessionEnum() - sLevel 50 on NWSERVER and VSERVER
 *    NetSessionGetInfo() - not supported on peer servers
 ****************************************************************}

(*	NetSessionDel (Admin only)
 *
 *
 *	API_FUNCTION NetSessionDel( servername, clientname, reserved )
 *
 *	ENTRY
 *
 * 	servername;     asciz remote srv name, NULL if local
 *	clientname;     asciz remote computer name (returned by NetSessionEnum)
 *                               	of session being deleted
 *                  In the case of a Win95 NWSERVER, the clientname should be the
 *                  ascii connection number
 *	reserved;       session key returned by NetSessionEnum
 *
 * 	EXIT
 *
 *	0 = success
 *	NERR_NetNotStarted
 *  ERROR_BAD_NETPATH
 *	NERR_ServerNotStarted
 *	ERROR_INVALID_LEVEL
 *	NERR_RemoteErr
 *	NERR_RemoteOnly
 * 	ERROR_ACCESS_DENIED
 *	NERR_BufTooSmall
 *	NERR_ClientNameNotFound
 *
 *)
function NetSessionDel(const pszServer, pszClientName: PChar;sReserved: short): DWORD; stdcall;

(*	NetSessionEnum
 *
 *	API_FUNCTION NetSessionEnum( servername,
 *				       level,
 *				       buf,
 *				       buflen,
 *				       entriesread,
 *				       totalentries )
 * ENTRY:
 *  servername;     asciz remote srv name, NULL if local
 *  level;          level of detail requested;
 *                  (50 for Win95 peer servers)
 *  buf;            for returned entries
 *                  (Buffer contains an array of session_info
 *                  structures.)
 *  buflen;         size of buffer on call;
 *  entriesread;    # of entries supplied on return
 *  totalentries;   total # of entries available
 *
 * EXIT:
 *  0 = success
 *  NERR_NetNotStarted
 *  NERR_ServerNotStarted
 *  ERROR_BAD_NETPATH
 *  ERROR_INVALID_LEVEL
 *  NERR_RemoteErr
 *  ERROR_MORE_DATA
 *  ERROR_ACCESS_DENIED
 *)
function NetSessionEnum(const pszServer: PChar;
                   sLevel: short;
                   pbBuffer: Pointer;
                   cbBuffer: Word;
                   var pcEntriesRead,pcTotalAvail: Word): DWORD; stdcall;

function NetSessionGetInfo(const pszServer,pszClientName: PChar;
                      sLevel: short;
                      pbBuffer: PChar;
                      cbBuffer: Word;
                      var pcbTotalAvail: Word): DWORD; stdcall;

{- Data structure templates - SESSION -}
type
  Psession_info_0 = ^Tsession_info_0;
  _session_info_0 = packed record
    sesi_cname: pchar;     // client name (no backslashes)
  end;  (* _session_info_0 *)
  Tsession_info_0 = _session_info_0;

  Psession_info_1 = ^Tsession_info_1;
  _session_info_1 = packed record
    sesi_cname: pchar;      // name of the computer that established the session.
    sesi_username: pchar;   // name of the user who established the session.
    sesi_num_conns: Word;
    sesi_num_opens: Word;   // number of files, devices, and pipes opened during the session.
    sesi_num_users: Word;
    sesi_time: dword;       // number of seconds a session has been active.
    sesi_idle_time: dword;  // number of seconds a session has been idle.
    sesi_user_flags: dword; // how the user established the session:
                             // SESS_GUEST = The sesi1_username
                             //   member established the session using
                             //   a guest account.
                             // SESS_NOENCRYPTION = The sesi1_username
                             //   member established the session
                             //   without using password encryption.
  end;  (* _session_info_1 *)
  Tsession_info_1 = _session_info_1;

  Psession_info_2 = ^Tsession_info_2;
  _session_info_2 = packed record
    sesi_cname: PChar;
    sesi_username: PChar;
    sesi_num_conns: Word;
    sesi_num_opens: Word;
    sesi_num_users: Word;
    sesi_time: Longword;
    sesi_idle_time: Longword;
    sesi_user_flags: Longword;
    sesi_cltype_name: PChar;
  end;  (* _session_info_2 *)
  Tsession_info_2 = _session_info_2;

  Psession_info_10 = ^Tsession_info_10;
  _session_info_10 = packed record
    sesi_cname: PChar;
    sesi_username: PChar;
    sesi_time: Longword;
    sesi_idle_time: Longword;
  end;  (* _session_info_10 *)
  Tsession_info_10 = _session_info_10;

  Psession_info_50 = ^Tsession_info_50;
  Psession_info_50_array = ^Tsession_info_50_array;
  _session_info_50 = packed record
    sesi_cname: PChar;          //remote computer name (connection id in Netware)
    sesi_username: PChar;
    sesi_key: Longword;         // used to delete session (not used in Netware)
    sesi_num_conns: Word;
    sesi_num_opens: Word;       //not available in Netware
    sesi_time: Longword;
    sesi_idle_time: Longword;   //not available in Netware
    sesi_protocol: Byte;
    pad1: Byte;
  end;	(* _session_info_50 *)
  Tsession_info_50 = _session_info_50;
  Tsession_info_50_array = array [0..MaxInt div sizeof(Tsession_info_50)-1] of Tsession_info_50;


{- Special values and constants - SESSION -}

{ Bits defined in sesi1_user_flags. }
const
  SESS_GUEST		= 1;	(* session is logged on as a guest *)
  SESS_NOENCRYPTION	= 2;	(* session is not using encryption *)
  SESI1_NUM_ELEMENTS	= 8;
  SESI2_NUM_ELEMENTS	= 9;


{- Connection Class -}

{****************************************************************
 *  Function prototypes - CONNECTION
 *  ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 *  Peer Server Support
 *    NetConnectionEnum - sLevel 50 on VSERVER and NWSERVER
 *                        On NWSERVER, this API doesnt provide more
 *                        information than NetSessionEnum
 ****************************************************************}

(*	NetConnectionEnum (Admin only)
 *
 *	API_FUNCTION NetConnectionEnum( servername,
 *					  qualifier,
 *					  level,
 *					  buf,
 *					  buflen,
 *					  totalavail )
 *
 * ENTRY:
 *	servername;     asciz remote srv name, NULL if local
 *	qualifier;      netname or client computer name.
 *                      computer name should be prefaced by '\\'.
 *	level;	    	level of info requested
 *	buf;            for returned entry
 *	buflen;         size of buffer
 *	totalavail;     total size needed for buffer
 *
 * EXIT:
 *	0 = success
 *	NERR_NetNotStarted
 *	NERR_ServerNotStarted
 *	ERROR_INVALID_LEVEL
 *	NERR_RemoteErr
 *	NERR_RemoteOnly		(DOS)
 *	ERROR_MORE_DATA
 * 	ERROR_ACCESS_DENIED
 *	NERR_ClientNameNotFound
 *	NERR_NetNameNotFound
 *
 *	Buffer contents on response (format for a single entry):
 *   	    Level 50 contains a "struct connection_info_50".
 *)
function NetConnectionEnum(const pszServer,pszQualifier:PChar;   (* upper case *)
                      sLevel: short;pbBuffer: PChar;cbBuffer: Word;var pcEntriesRead,pcTotalAvail: Word): DWORD; stdcall;

{- Data structure templates - CONNECTION -}
type
  Pconnection_info_0 = ^Tconnection_info_0;
  _connection_info_0 = packed record
    coni_id: Word;
  end;  (* _connection_info_0 *)
  Tconnection_info_0 = _connection_info_0;

  Pconnection_info_1 = ^Tconnection_info_1;
  _connection_info_1 = packed record
    coni_id: Word;
    coni_type: Word;
    coni_num_opens: Word;
    coni_num_users: Word;
    coni_time: Longword;
    coni_username: PChar;
    coni_netname: PChar;
  end;  (* _connection_info_1 *)
  Tconnection_info_1 = _connection_info_1;

  Pconnection_info_50 = ^Tconnection_info_50;
  _connection_info_50 = packed record
    coni_type: Word;            // share type
    coni_num_opens: Word;	//not used in Netware
    coni_time: Longword;
    coni_netname: PChar;        // share name
    coni_username: PChar;       // user connected to share
  end; (* _connection_info_50 *)
  Tconnection_info_50 = _connection_info_50;


{- File Class -}

{****************************************************************
 * Function prototypes - FILE
 * ~~~~~~~~~~~~~~~~~~~~~~~~~~
 *  Peer Server Support
 *    NetFileEnum - sLevel 50 on VSERVER and NWSERVER
 *    NetFileClose2 - VSERVER only
 ****************************************************************}

(*	NetFileClose2
 *
 *	int FAR PASCAL	NetFileClose2( servername, fileid )
 *
 * ENTRY:
 *	servername;     asciz remote srv name, NULL if local
 *	fileid;     	file id supplied by NetFileEnum
 *
 * EXIT:
 *	0 = success
 *	NERR_NetNotStarted
 *	NERR_ServerNotStarted
 *	NERR_RemoteErr
 * 	ERROR_ACCESS_DENIED
 *	NERR_FileIdNotFound
 *)

function NetFileClose2(const pszServer: PChar; ulFileId: Longword): DWORD; stdcall;

(*	NetFileEnum (Admin Only)
 *
 *	int FAR PASCAL NetFileEnum( servername,
 *				    level,
 *				    buf,
 *				    buflen,
 *				    entriesread,
 *				    totalentries )
 *
 * ENTRY:
 *	servername;     asciz remote srv name, NULL if local
 *	basepath;	path qualifier for file matching
 *                      (not used for Win95 NWSERVER)
 *	level;          level of detail requested;
 *                      (50 for Win95 peer servers)
 *	buf;            for returned entries
 *	buflen;         size of buffer on call;
 *	entriesread;    # of entries supplied on return
 *	totalentries;   total # of entries available
 *
 * EXIT:
 *	0 = success
 *	NERR_RemoteOnly
 *	NERR_NetNotStarted
 *	NERR_ServerNotStarted
 *	ERROR_INVALID_LEVEL
 *	NERR_RemoteErr
 *	ERROR_MORE_DATA
 * 	ERROR_ACCESS_DENIED
 *
 *
 *	Buffer contents on response (format for a single entry):
 *   	    Level 0 contains a "struct file_info_0".
 *   	    Level 50 contains a "struct file_info_50".
 *
 *)

function NetFileEnum(const pszServer,pszBasePath: PChar;sLevel: short;pbBuffer: PChar;cbBuffer: Word;var pcEntriesRead,pcTotalAvail: Word): DWORD; stdcall;

{- Data structure templates - FILE -}
type
  Pfile_info_0 = ^Tfile_info_0;
  _file_info_0 = packed record
    fi_id: Word;
  end;  (* _file_info_0 *)
  Tfile_info_0 = _file_info_0;

  Pfile_info_1 = ^Tfile_info_1;
  _file_info_1 = packed record
    fi_id: Word;
    fi_permissions: Word;
    fi_num_locks: Word;
    fi_pathname: PChar;
    fi_username: PChar;
  end;  (* _file_info_1 *)
  Tfile_info_1 = _file_info_1;

  Pfile_info_2 = ^Tfile_info_2;
  _file_info_2 = packed record
    fi_id: Longword;
  end;  (* _file_info_2 *)
  Tfile_info_2 = _file_info_2;

  Pfile_info_3 = ^Tfile_info_3;
  _file_info_3 = packed record
    fi_id: Longword;
    fi_permissions: Word;
    fi_num_locks: Word;
    fi_pathname: PChar;
    fi_username: PChar;
  end;  (* _file_info_3 *)
  Tfile_info_3 = _file_info_3;

  Pfile_info_50 = ^Tfile_info_50;
  _file_info_50 = packed record
    fi_id: Longword;              // not used on NWSERVER
    fi_permissions: Word;    // not available on NWSERVER
    fi_num_locks: Word;      // not available on NWSERVER
    fi_pathname: PChar;
    fi_username: PChar;
    fi_sharename: PChar;
  end; (* _file_info_50 *)
  Tfile_info_50 = _file_info_50;

{- Special values and constants - FILE -}

const			     	(* bit values for permissions *)
  PERM_FILE_READ	= $1;	(* user has read access *)
  PERM_FILE_WRITE	= $2;	(* user has write access *)
  PERM_FILE_CREATE	= $4;	(* user has create access *)

type
  PFRK = ^TFRK;
  res_file_enum_2 = packed record
    res_pad: Word;	      (* not used now *)
    res_fs: Word;             (* server type *)
    res_pro: Longword;        (* progressive *)
  end;  (* res_file_enum_2 *)
  TFRK = res_file_enum_2;
  FRK = res_file_enum_2;
(* don't how ...
const
  FRK_INIT(f)
    begin
      (f).res_pad = 0L;
      (f).res_fs = 0;
      (f).res_pro = 0;
    end;
*)

{- Server Class -}

{****************************************************************
 * Function prototypes - SERVER
 * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Peer Server Support
 *   NetServerGetInfo - sLevel 1,50 on NWSERVER, VSERVER
 ****************************************************************}

(* 6.2  NetServerGetInfo
 *
 * Purpose: Read the current configuration parameters of the server.
 *
 * int FAR PASCAL
 * NetServerGetInfo( servername, level, buf, buflen, totalavail )
 * PChar  servername;      asciz remote server name or NULL if local
 * short  level;           level of information to be returned
 * PChar  buf;             for returned data
 * Word   buflen;          size of buffer
 * Word   vartotalavail;   total size needed for buffer
 *
 * Buffer contents on response (format for a single entry):
 *     Level 1 contains a "struct server_info_1".
 *     Level 50 contains a "struct server_info_50".
 *
 * If the buflen is not large enough for all of the information, the call
 * will return as much as will fit in the buffer.
 *
 * Returns 0 if successful. Error return information:
 *
 *     - ERROR_INVALID_LEVEL       - Level parameter specified is invalid
 *     - ERROR_INVALID_PARAMETER   - An invalid input parameter was detected.
 *     - NERR_NetNotStarted        - Network not installed on local machine
 *     - NERR_ServerNotStarted     - Server is not started
 *     - NERR_BufTooSmall          - The buffer supplied was to small to
 *                                   return the fixed length structure
 *				     requested.
 *     - NERR_MoreData             - The buffer supplied was too small to
 *				     return all the information available
 *				     for this server.
 *
 *)

function NetServerGetInfo(const pszServer: PChar;sLevel: short;pbBuffer: PChar;cbBuffer: Word;var pcbTotalAvail: Word): DWORD; stdcall;

{- Data structure templates - SERVER -}
type

  Pserver_info_0 = ^Tserver_info_0;
  _server_info_0 = packed record
    sv_name: array [0..CNLEN] of Char; 	(* Server name *)
  end;	 (* _server_info_0 *)
  Tserver_info_0 = _server_info_0;

  Pserver_info_100 = ^Tserver_info_100;
  _server_info_100 = packed record
    sv_platform_id: DWord;
    sv_name: array [0..CNLEN] of Char; 	(* Server name *)
  end;	 (* _server_info_0 *)
  Tserver_info_100 = _server_info_100;


  Pserver_info_1 = ^Tserver_info_1;
  _server_info_1 = packed record
    sv_name: array [0..CNLEN] of Char;
    sv_version_major: Byte;	   (* Major version # of net   *)
    sv_version_minor: Byte;	   (* Minor version # of net   *)
    sv_type: Longword;	     	   (* Server type 		    *)
    sv_comment: PChar; 		   (* Exported server comment  *)
  end;	 (* _server_info_1 *)
  Tserver_info_1 = _server_info_1;

  Pserver_info_101 = ^Tserver_info_101;
  _server_info_101 = packed record
    sv_platform_id: DWord;
    sv_name: array [0..CNLEN] of Char;
    sv_version_major: Byte;
    sv_version_minor: Byte;
    sv_type: Longword;
    sv_comment: PChar;
  end;	 (* _server_info_101 *)
  Tserver_info_101 = _server_info_101;

(* NOTE struct prefix must equal server_info_1 like below! *)

  Pserver_info_50 = ^Tserver_info_50;
  _server_info_50 = packed record
    sv_name: array [0..CNLEN] of Char;
    sv_version_major: Byte;	(* Major version # of net   *)
    sv_version_minor: Byte;	(* Minor version # of net   *)
    sv_type: Longword;	     	(* Server type 		    *)
    sv_comment: PChar; 		(* Exported server comment  *)
    sv_security: Word;    		(* SV_SECURITY_* (see below) *)
    sv_auditing: Word;                (* 0 = no auditing; nonzero = auditing *)
    sv_container: PChar;		(* Security server/domain    *)
    sv_ab_server: PChar;		(* Address book server       *)
    sv_ab_dll: PChar;		        (* Address book provider DLL *)
  end;	(* _server_info_50 *)
  Tserver_info_50 = _server_info_50;

  Pserver_info_2 = ^Tserver_info_2;
  _server_info_2 = packed record
    sv_name: array [0..CNLEN] of Char;
    sv_version_major: Byte;
    sv_version_minor: Byte;
    sv_type: Longword;
    sv_comment: PChar;
    sv_ulist_mtime: Longword; (* User list, last modification time    *)
    sv_glist_mtime: Longword; (* Group list, last modification time   *)
    sv_alist_mtime: Longword; (* Access list, last modification time  *)
    sv_users: Word;       (* max number of users allowed          *)
    sv_disc: Word;        (* auto-disconnect timeout(in minutes)  *)
    sv_alerts: PChar;     (* alert names (semicolon separated)    *)
    sv_security: Word;    (* SV_USERSECURITY or SV_SHARESECURITY  *)
    sv_auditing: Word;    (* 0 = no auditing; nonzero = auditing  *)
    sv_numadmin: Word;    (* max number of administrators allowed *)
    sv_lanmask: Word;     (* bit mask representing the srv'd nets *)
    sv_hidden: Word;      (* 0 = visible; nonzero = hidden        *)
    sv_announce: Word;    (* visible server announce rate (sec)   *)
    sv_anndelta: Word;    (* announce randomize interval (sec)    *)
                          (* name of guest account                *)
    sv_guestacct: array [0..LM20_UNLEN] of Char;
    sv_pad1: Byte;	    (* Word alignment pad byte		    *)
    sv_userpath: PChar;    (* ASCIIZ path to user directories      *)
    sv_chdevs: Word;      (* max # shared character devices       *)
    sv_chdevq: Word;      (* max # character device queues        *)
    sv_chdevjobs: Word;   (* max # character device jobs          *)
    sv_connections: Word; (* max # of connections		    *)
    sv_shares: Word;	    (* max # of shares			    *)
    sv_openfiles: Word;   (* max # of open files		    *)
    sv_sessopens: Word;   (* max # of open files per session	    *)
    sv_sessvcs: Word;     (* max # of virtual circuits per client *)
    sv_sessreqs: Word;    (* max # of simul. reqs. from a client  *)
    sv_opensearch: Word;  (* max # of open searches		    *)
    sv_activelocks: Word; (* max # of active file locks           *)
    sv_numreqbuf: Word;   (* number of server (standard) buffers  *)
    sv_sizreqbuf: Word;   (* size of svr (standard) bufs (bytes)  *)
    sv_numbigbuf: Word;   (* number of big (64K) buffers          *)
    sv_numfiletasks: Word;(* number of file worker processes      *)
    sv_alertsched: Word;  (* alert counting interval (minutes)    *)
    sv_erroralert: Word;  (* error log alerting threshold         *)
    sv_logonalert: Word;  (* logon violation alerting threshold   *)
    sv_accessalert: Word; (* access violation alerting threshold  *)
    sv_diskalert: Word;   (* low disk space alert threshold (KB)  *)
    sv_netioalert: Word;  (* net I/O error ratio alert threshold  *)
                          (*  (tenths of a percent)               *)
    sv_maxauditsz: Word;  (* Maximum audit file size (KB)        *)
    sv_srvheuristics: PChar; (* performance related server switches*)
  end;	(* _server_info_2 *)
  Tserver_info_2 = _server_info_2;

  Pserver_info_3 = ^Tserver_info_3;
  _server_info_3 = packed record
    sv_name: array [0..CNLEN] of Char;
    sv_version_major: Byte;
    sv_version_minor: Byte;
    sv_type: Longword;
    sv_comment: PChar;
    sv_ulist_mtime: Longword; (* User list, last modification time    *)
    sv_glist_mtime: Longword; (* Group list, last modification time   *)
    sv_alist_mtime: Longword; (* Access list, last modification time  *)
    sv_users: Word;	     (* max number of users allowed	     *)
    sv_disc: Word;	    (* auto-disconnect timeout(in minutes)  *)
    sv_alerts: PChar;     (* alert names (semicolon separated)    *)
    sv_security: Word;    (* SV_USERSECURITY or SV_SHARESECURITY  *)
    sv_auditing: Word;    (* 0 = no auditing; nonzero = auditing  *)
    sv_numadmin: Word;    (* max number of administrators allowed *)
    sv_lanmask: Word;     (* bit mask representing the srv'd nets *)
    sv_hidden: Word;      (* 0 = visible; nonzero = hidden	     *)
    sv_announce: Word;    (* visible server announce rate (sec)   *)
    sv_anndelta: Word;    (* announce randomize interval (sec)    *)
      		          (* name of guest account		    *)
    sv_guestacct: array [0..LM20_UNLEN] of Char;
    sv_pad1: Byte;	    (* Word alignment pad byte		    *)
    sv_userpath: PChar;    (* ASCIIZ path to user directories	     *)
    sv_chdevs: Word;      (* max # shared character devices	     *)
    sv_chdevq: Word;      (* max # character device queues	     *)
    sv_chdevjobs: Word;   (* max # character device jobs	     *)
    sv_connections: Word; (* max # of connections		    *)
    sv_shares: Word;     (* max # of shares			    *)
    sv_openfiles: Word;   (* max # of open files		    *)
    sv_sessopens: Word;   (* max # of open files per session     *)
    sv_sessvcs: Word;     (* max # of virtual circuits per client *)
    sv_sessreqs: Word;    (* max # of simul. reqs. from a client  *)
    sv_opensearch: Word;  (* max # of open searches		    *)
    sv_activelocks: Word; (* max # of active file locks	     *)
    sv_numreqbuf: Word;   (* number of server (standard) buffers  *)
    sv_sizreqbuf: Word;   (* size of svr (standard) bufs (bytes)  *)
    sv_numbigbuf: Word;   (* number of big (64K) buffers	     *)
    sv_numfiletasks: Word;(* number of file worker processes      *)
    sv_alertsched: Word;  (* alert counting interval (minutes)    *)
    sv_erroralert: Word;  (* error log alerting threshold	     *)
    sv_logonalert: Word;  (* logon violation alerting threshold   *)
    sv_accessalert: Word; (* access violation alerting threshold  *)
    sv_diskalert: Word;   (* low disk space alert threshold (KB)  *)
    sv_netioalert: Word;  (* net I/O error ratio alert threshold  *)
                          (*  (tenths of a percent)               *)
    sv_maxauditsz: Word;  (* Maximum audit file size (KB)	     *)
    sv_srvheuristics: PChar; (* performance related server switches*)
    sv_auditedevents: Longword; (* Audit event control mask	     *)
    sv_autoprofile: Word; (* (0,1,2,3) = (NONE,LOAD,SAVE,or BOTH) *)
    sv_autopath: PChar;    (* file pathname (where to load & save) *)
  end;	(* _server_info_3 *)
  Tserver_info_3 = _server_info_3;

{- Special values and constants - SERVER -}

{ Mask to be applied to svX_version_major in order to obtain
  the major version number.}

const
  MAJOR_VERSION_MASK	 = $0F;

{ Bit-mapped values for svX_type fields. X = 1, 2 or 3. }
  SV_TYPE_WORKSTATION	     = $00000001; 	// All LAN Manager workstations
  SV_TYPE_SERVER	     = $00000002; 	// All LAN Manager servers
  SV_TYPE_SQLSERVER	     = $00000004;	// Any server running with Microsoft SQL Server
  SV_TYPE_DOMAIN_CTRL	     = $00000008;	// Primary domain controller
  SV_TYPE_DOMAIN_BAKCTRL     = $00000010;	// Backup domain controller
  SV_TYPE_TIMESOURCE	     = $00000020;	// Server running the Timesource service
  SV_TYPE_AFP	             = $00000040;	// Apple File Protocol servers
  SV_TYPE_NOVELL	     = $00000080;	// Novell servers (This flag is also set by Win95 NWSERVER)
  SV_TYPE_DOMAIN_MEMBER	     = $00000100;	// LAN Manager 2.x Domain Member
  SV_TYPE_LOCAL_LIST_ONLY    = $40000000;	// Servers maintained by the browser
  SV_TYPE_PRINT	             = $00000200;	// Server sharing print queue
  SV_TYPE_DIALIN	     = $00000400;	// Server running dial-in service
  SV_TYPE_XENIX_SERVER	     = $00000800;	// Xenix server
  SV_TYPE_MFPN	             = $00004000;	// Microsoft File and Print for Netware
  SV_TYPE_NT	             = $00001000;	// Windows NT (either Workstation or Server)
  SV_TYPE_WFW	             = $00002000;	// Server running Windows for Workgroups
  SV_TYPE_SERVER_NT	     = $00008000;	// Windows NT non-DC server
  SV_TYPE_POTENTIAL_BROWSER  = $00010000;	// Server that can run the Browser service
  SV_TYPE_BACKUP_BROWSER     = $00020000;	// Server running a Browser service as backup
  SV_TYPE_MASTER_BROWSER     = $00040000;	// Server running the master Browser service
  SV_TYPE_DOMAIN_MASTER	     = $00080000;	// Server running the domain master Browser
  SV_TYPE_DOMAIN_ENUM	     = $80000000;	// Primary Domain
  SV_TYPE_WINDOWS	     = $00400000;	// Windows 95 or later
  SV_TYPE_ALL	             = $FFFFFFFF;	// All servers (handy for NetServerEnum2)

{ Special value for svX_disc that specifies infinite disconnect
  time. X = 2 or 3.}
const
  SV_NODISC		 = $FFFF;       (* No autodisconnect timeout enforced *)

{ Values of svX_security field. X = 2 or 3. }
  SV_USERSECURITY	 = 1;
  SV_SHARESECURITY	 = 0;

{ Values of svX_security field. X = 50.
  For Win95 NWSERVER, the only possible returned value is SV_SECURITY_NETWARE.}
  SV_SECURITY_SHARE	= 0;	(* Share-level *)
  SV_SECURITY_WINNT	= 1;	(* User-level - Windows NT workst'n *)
  SV_SECURITY_WINNTAS	= 2;	(* User-level - Windows NT domain *)
  SV_SECURITY_NETWARE	= 3;	(* User-level - NetWare 3.x bindery *)

{ Values of svX_hidden field. X = 2 or 3.}
  SV_HIDDEN		= 1;
  SV_VISIBLE		= 0;
  SVI1_NUM_ELEMENTS	= 5;
  SVI2_NUM_ELEMENTS	= 44;
  SVI3_NUM_ELEMENTS	= 45;


{ Masks describing AUTOPROFILE parameters}
  SW_AUTOPROF_LOAD_MASK	= $1;
  SW_AUTOPROF_SAVE_MASK	= $2;


{- Security Class -}
{****************************************************************
 * Function prototypes - SECURITY
 * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 ****************************************************************}

function NetSecurityGetInfo(const pszServer: PChar;sLevel: short;pbBuffer: PChar;cbBuffer: Word;var pcbTotalAvail: Word): DWORD; stdcall;

{- Data structure templates - SECURITY -}
type
  Psecurity_info_1 = ^Tsecurity_info_1;
  _security_info_1 = packed record
    sec_security: Longword;    (* SEC_SECURITY_* (see below) *)
    sec_container: PChar;      (* Security server/domain     *)
    sec_ab_server: PChar;      (* Address book server        *)
    sec_ab_dll: PChar;	       (* Address book provider DLL  *)
  end;	(* _security_info_1 *)
  Tsecurity_info_1 = _security_info_1;


{- Special values and constants - SECURITY -}

{ Values of secX_security field. X = 1. }
const
  SEC_SECURITY_SHARE	= SV_SECURITY_SHARE;
  SEC_SECURITY_WINNT	= SV_SECURITY_WINNT;
  SEC_SECURITY_WINNTAS	= SV_SECURITY_WINNTAS;
  SEC_SECURITY_NETWARE	= SV_SECURITY_NETWARE;

  function ExpandNError(lwNError: longword): string;
  function ExpandServerType(lwSType: longword): string;

const
  svrlib  = 'svrapi.dll';

implementation

{- Externals from svrapi.dll -}
  function NetAccessAdd; external svrlib name 'NetAccessAdd';
  function NetAccessCheck; external svrlib name 'NetAccessCheck';
  function NetAccessDel; external svrlib name 'NetAccessDel';
  function NetAccessEnum; external svrlib name 'NetAccessEnum';
  function NetAccessGetInfo; external svrlib name 'NetAccessGetInfo';
  function NetAccessSetInfo; external svrlib name 'NetAccessSetInfo';
  function NetAccessGetUserPerms; external svrlib name 'NetAccessGetUserPerms';
  function NetShareAdd; external svrlib name 'NetShareAdd';
  function NetShareDel; external svrlib name 'NetShareDel';
  function NetShareEnum; external svrlib name 'NetShareEnum';
  function NetShareGetInfo; external svrlib name 'NetShareGetInfo';
  function NetShareSetInfo; external svrlib name 'NetShareSetInfo';
  function NetSessionDel; external svrlib name 'NetSessionDel';
  function NetSessionEnum; external svrlib name 'NetSessionEnum';
  function NetSessionGetInfo; external svrlib name 'NetSessionGetInfo';
  function NetConnectionEnum; external svrlib name 'NetConnectionEnum';
  function NetFileClose2; external svrlib name 'NetFileClose2';
  function NetFileEnum; external svrlib name 'NetFileEnum';
  function NetServerGetInfo; external svrlib name 'NetServerGetInfo';
  function NetSecurityGetInfo; external svrlib name 'NetSecurityGetInfo';
{- Hand made -}
  function ExpandServerType(lwSType: longword): string;
  begin
    case lwSType of
      SV_TYPE_WORKSTATION:  result:= 'All LAN Manager workstations';
      SV_TYPE_SERVER:  result:= 'All LAN Manager servers';
      SV_TYPE_SQLSERVER:  result:= 'Any server running with Microsoft SQL Server';
      SV_TYPE_DOMAIN_CTRL:  result:= 'Primary domain controller';
      SV_TYPE_DOMAIN_BAKCTRL:  result:= 'Backup domain controller';
      SV_TYPE_TIMESOURCE:  result:= 'Server running the Timesource service';
      SV_TYPE_AFP:  result:= 'Apple File Protocol servers';
      SV_TYPE_NOVELL:  result:= 'Novell servers';
      SV_TYPE_DOMAIN_MEMBER:  result:= 'LAN Manager 2.x Domain Member';
      SV_TYPE_LOCAL_LIST_ONLY:  result:= 'Servers maintained by the browser';
      SV_TYPE_PRINT:  result:= 'Server sharing print queue';
      SV_TYPE_DIALIN:  result:= 'Server running dial-in service';
      SV_TYPE_XENIX_SERVER:  result:= 'Xenix server';
      SV_TYPE_MFPN:  result:= 'Microsoft File and Print for Netware';
      SV_TYPE_NT:  result:= 'Windows NT (either Workstation or Server)';
      SV_TYPE_WFW:  result:= 'Server running Windows for Workgroups';
      SV_TYPE_SERVER_NT:  result:= 'Windows NT non-DC server';
      SV_TYPE_POTENTIAL_BROWSER:  result:= 'Server that can run the Browser service';
      SV_TYPE_BACKUP_BROWSER:  result:= 'Server running a Browser service as backup';
      SV_TYPE_MASTER_BROWSER:  result:= 'Server running the master Browser service';
      SV_TYPE_DOMAIN_MASTER:  result:= 'Server running the domain master Browser';
      SV_TYPE_DOMAIN_ENUM:  result:= 'Primary Domain';
      SV_TYPE_WINDOWS:  result:= 'Windows 95 or later';
      SV_TYPE_ALL:  result:= 'All servers';
    else
      result:= 'Unknown server type ('+inttostr(lwSType)+')';
    end;
  end;

  function ExpandNError(lwNError: longword): string;
  begin
    case lwNError of
      0: result:= 'success.';
      ERROR_INVALID_LEVEL: result:= 'The system call level is incorrect.';
      ERROR_ACCESS_DENIED: result:= 'Access is denied.';
      ERROR_BAD_NET_NAME: result:= 'The network name cannot be found.';
      ERROR_BAD_NET_RESP: result:= 'The specified server cannot perform the requested operation.';
      ERROR_BAD_NETPATH: result:= 'The network path was not found.';
      ERROR_NEGATIVE_SEEK: result:= 'An attempt was made to move the file pointer before the beginning of the file.';
      ERROR_NESTING_NOT_ALLOWED: result:= 'Can'+chr($27)+'t nest calls to LoadModule.';
      ERROR_NETLOGON_NOT_STARTED: result:= 'An attempt was made to logon, but the network logon service was not started.';
      ERROR_NET_WRITE_FAULT: result:= 'A write fault occurred on the network.';
      ERROR_NETNAME_DELETED: result:= 'The specified network name is no longer available.';
      ERROR_NETWORK_ACCESS_DENIED: result:= 'Network access is denied.';
      ERROR_NETWORK_BUSY: result:= 'The network is busy.';
      ERROR_NETWORK_UNREACHABLE: result:= 'The remote network is not reachable by the transport.';
      NERR_NetNotStarted: result:= 'The workstation driver is not installed.';
      NERR_UnknownServer: result:= 'The server could not be located.';
      NERR_ShareMem: result:= 'An internal error occurred.  The network cannot access a shared memory segment.';
      NERR_NoNetworkResource: result:= 'A network resource shortage occurred .';
      NERR_RemoteOnly: result:= 'This operation is not supported on workstations.';
      NERR_DevNotRedirected: result:= 'The device is not connected.';
      NERR_ServerNotStarted: result:= 'The Server service is not started.';
      NERR_ItemNotFound: result:= 'The queue is empty.';
      NERR_UnknownDevDir: result:= 'The device or directory does not exist.';
      NERR_RedirectedPath: result:= 'The operation is invalid on a redirected resource.';
      NERR_DuplicateShare: result:= 'The name has already been shared.';
      NERR_NoRoom: result:= 'The server is currently out of the requested resource.';
      NERR_TooManyItems: result:= 'Requested addition of items exceeds the maximum allowed.';
      NERR_InvalidMaxUsers: result:= 'The Peer service supports only two simultaneous users.';
      NERR_BufTooSmall: result:= 'The API return buffer is too small.';
      NERR_RemoteErr: result:= 'A remote API error occurred. ';
      NERR_LanmanIniError: result:= 'An error occurred when opening or reading the configuration file.';
      NERR_NetworkError: result:= 'A general network error occurred.';
      NERR_WkstaInconsistentState: result:= 'The Workstation service is in an inconsistent state. Restart the computer before restarting the Workstation service.';
      NERR_WkstaNotStarted: result:= 'The Workstation service has not been started.';
      NERR_BrowserNotStarted: result:= 'The requested information is not available.';
      NERR_InternalError: result:= 'An internal Windows NT error occurred.';
      NERR_BadTransactConfig: result:= 'The server is not configured for transactions.';
      NERR_InvalidAPI: result:= 'The requested API is not supported on the remote server.';
      NERR_BadEventName: result:= 'The event name is invalid.';
      NERR_DupNameReboot: result:= 'The computer name already exists on the network. Change it and restart the computer.';
      NERR_CfgCompNotFound: result:= 'The specified component could not be found in the configuration information.';
      NERR_CfgParamNotFound: result:= 'The specified parameter could not be found in the configuration information.';
      NERR_LineTooLong: result:= 'A line in the configuration file is too long.';
      NERR_QNotFound: result:= 'The printer does not exist.';
      NERR_JobNotFound: result:= 'The print job does not exist.';
      NERR_DestNotFound: result:= 'The printer destination cannot be found.';
      NERR_DestExists: result:= 'The printer destination already exists.';
      NERR_QExists: result:= 'The printer queue already exists.';
      NERR_QNoRoom: result:= 'No more printers can be added.';
      NERR_JobNoRoom: result:= 'No more print jobs can be added. ';
      NERR_DestNoRoom: result:= 'No more printer destinations can be added.';
      NERR_DestIdle: result:= 'This printer destination is idle and cannot accept control operations.';
      NERR_DestInvalidOp: result:= 'This printer destination request contains an invalid control function.';
      NERR_ProcNoRespond: result:= 'The print processor is not responding.';
      NERR_SpoolerNotLoaded: result:= 'The spooler is not running.';
      NERR_DestInvalidState: result:= 'This operation cannot be performed on the print destination in its current state.';
      NERR_QInvalidState: result:= 'This operation cannot be performed on the printer queue in its current state.';
      NERR_JobInvalidState: result:= 'This operation cannot be performed on the print job in its current state.';
      NERR_SpoolNoMemory: result:= 'A spooler memory allocation failure occurred.';
      NERR_DriverNotFound: result:= 'The device driver does not exist.';
      NERR_DataTypeInvalid: result:= 'The data type is not supported by the print processor.';
      NERR_ProcNotFound: result:= 'The print processor is not installed.';
      NERR_ServiceTableLocked: result:= 'The service database is locked.';
      NERR_ServiceTableFull: result:= 'The service table is full.';
      NERR_ServiceInstalled: result:= 'The requested service has already been started.';
      NERR_ServiceEntryLocked: result:= 'The service does not respond to control actions.';
      NERR_ServiceNotInstalled: result:= 'The service has not been started.';
      NERR_BadServiceName: result:= 'The service name is invalid.';
      NERR_ServiceCtlTimeout: result:= 'The service is not responding to the control function.';
      NERR_ServiceCtlBusy: result:= 'The service control is busy.';
      NERR_BadServiceProgName: result:= 'The configuration file contains an invalid service program name.';
      NERR_ServiceNotCtrl: result:= 'The service could not be controlled in its present state.';
      NERR_ServiceKillProc: result:= 'The service ended abnormally.';
      NERR_ServiceCtlNotValid: result:= 'The requested pause or stop is not valid for this service.';
      NERR_NotInDispatchTbl: result:= 'The service control dispatcher could not find the service name in the dispatch table.';
      NERR_BadControlRecv: result:= 'The service control dispatcher pipe read failed.';
      NERR_ServiceNotStarting: result:= 'A thread for the new service could not be created.';
      NERR_AlreadyLoggedOn: result:= 'This workstation is already logged on to the local-area network.';
      NERR_NotLoggedOn: result:= 'The workstation is not logged on to the local-area network.';
      NERR_BadUsername: result:= 'The user name or group name parameter is invalid. ';
      NERR_BadPassword: result:= 'The password parameter is invalid.';
      NERR_UnableToAddName_W: result:= '@W The logon processor did not add the message alias.';
      NERR_UnableToAddName_F: result:= 'The logon processor did not add the message alias.';
      NERR_UnableToDelName_W: result:= '@W The logoff processor did not delete the message alias.';
      NERR_UnableToDelName_F: result:= 'The logoff processor did not delete the message alias.';
      NERR_LogonsPaused: result:= 'Network logons are paused.';
      NERR_LogonServerConflict: result:= 'A centralized logon-server conflict occurred.';
      NERR_LogonNoUserPath: result:= 'The server is configured without a valid user path.';
      NERR_LogonScriptError: result:= 'An error occurred while loading or running the logon script.';
      NERR_StandaloneLogon: result:= 'The logon server was not specified.  Your computer will be logged on as STANDALONE.';
      NERR_LogonServerNotFound: result:= 'The logon server could not be found. ';
      NERR_LogonDomainExists: result:= 'There is already a logon domain for this computer. ';
      NERR_NonValidatedLogon: result:= 'The logon server could not validate the logon.';
      NERR_ACFNotFound: result:= 'The security database could not be found.';
      NERR_GroupNotFound: result:= 'The group name could not be found.';
      NERR_UserNotFound: result:= 'The user name could not be found.';
      NERR_ResourceNotFound: result:= 'The resource name could not be found. ';
      NERR_GroupExists: result:= 'The group already exists.';
      NERR_UserExists: result:= 'The user account already exists.';
      NERR_ResourceExists: result:= 'The resource permission list already exists.';
      NERR_NotPrimary: result:= 'This operation is only allowed on the primary domain controller of the domain.';
      NERR_ACFNotLoaded: result:= 'The security database has not been started.';
      NERR_ACFNoRoom: result:= 'There are too many names in the user accounts database.';
      NERR_ACFFileIOFail: result:= 'A disk I/O failure occurred.';
      NERR_ACFTooManyLists: result:= 'The limit of 64 entries per resource was exceeded.';
      NERR_UserLogon: result:= 'Deleting a user with a session is not allowed.';
      NERR_ACFNoParent: result:= 'The parent directory could not be located.';
      NERR_CanNotGrowSegment: result:= 'Unable to add to the security database session cache segment.';
      NERR_SpeGroupOp: result:= 'This operation is not allowed on this special group.';
      NERR_NotInCache: result:= 'This user is not cached in user accounts database session cache.';
      NERR_UserInGroup: result:= 'The user already belongs to this group.';
      NERR_UserNotInGroup: result:= 'The user does not belong to this group.';
      NERR_AccountUndefined: result:= 'This user account is undefined.';
      NERR_AccountExpired: result:= 'This user account has expired.';
      NERR_InvalidWorkstation: result:= 'The user is not allowed to log on from this workstation.';
      NERR_InvalidLogonHours: result:= 'The user is not allowed to log on at this time. ';
      NERR_PasswordExpired: result:= 'The password of this user has expired.';
      NERR_PasswordCantChange: result:= 'The password of this user cannot change.';
      NERR_PasswordHistConflict: result:= 'This password cannot be used now.';
      NERR_PasswordTooShort: result:= 'The password is shorter than required.';
      NERR_PasswordTooRecent: result:= 'The password of this user is too recent to change. ';
      NERR_InvalidDatabase: result:= 'The security database is corrupted.';
      NERR_DatabaseUpToDate: result:= 'No updates are necessary to this replicant network/local security database.';
      NERR_SyncRequired: result:= 'This replicant database is outdated; synchronization is required.';
      NERR_UseNotFound: result:= 'The network connection could not be found.';
      NERR_BadAsgType: result:= 'This asg_type is invalid.';
      NERR_DeviceIsShared: result:= 'This device is currently being shared.';
      NERR_NoComputerName: result:= 'The computer name could not be added as a message alias.  The name may already exist on the network.';
      NERR_MsgAlreadyStarted: result:= 'The Messenger service is already started.';
      NERR_MsgInitFailed: result:= 'The Messenger service failed to start. ';
      NERR_NameNotFound: result:= 'The message alias could not be found on the network.';
      NERR_AlreadyForwarded: result:= 'This message alias has already been forwarded.';
      NERR_AddForwarded: result:= 'This message alias has been added but is still forwarded.';
      NERR_AlreadyExists: result:= 'This message alias already exists locally.';
      NERR_TooManyNames: result:= 'The maximum number of added message aliases has been exceeded.';
      NERR_DelComputerName: result:= 'The computer name could not be deleted.';
      NERR_LocalForward: result:= 'Messages cannot be forwarded back to the same workstation.';
      NERR_GrpMsgProcessor: result:= 'An error occurred in the domain message processor.';
      NERR_PausedRemote: result:= 'The message was sent, but the recipient has paused the Messenger service.';
      NERR_BadReceive: result:= 'The message was sent but not received.';
      NERR_NameInUse: result:= 'The message alias is currently in use. Try again later.';
      NERR_MsgNotStarted: result:= 'The Messenger service has not been started.';
      NERR_NotLocalName: result:= 'The name is not on the local computer.';
      NERR_NoForwardName: result:= 'The forwarded message alias could not be found on the network.';
      NERR_RemoteFull: result:= 'The message alias table on the remote station is full.';
      NERR_NameNotForwarded: result:= 'Messages for this alias are not currently being forwarded.';
      NERR_TruncatedBroadcast: result:= 'The broadcast message was truncated.';
      NERR_InvalidDevice: result:= 'This is an invalid device name.';
      NERR_WriteFault: result:= 'A write fault occurred.';
      NERR_DuplicateName: result:= 'A duplicate message alias exists on the network.';
      NERR_DeleteLater: result:= '@W This message alias will be deleted later.';
      NERR_IncompleteDel: result:= 'The message alias was not successfully deleted from all networks.';
      NERR_MultipleNets: result:= 'This operation is not supported on computers with multiple networks.';
      NERR_NetNameNotFound: result:= 'This shared resource does not exist.';
      NERR_DeviceNotShared: result:= 'This device is not shared.';
      NERR_ClientNameNotFound: result:= 'A session does not exist with that computer name.';
      NERR_FileIdNotFound: result:= 'There is not an open file with that identification number.';
      NERR_ExecFailure: result:= 'A failure occurred when executing a remote administration command.';
      NERR_TmpFile: result:= 'A failure occurred when opening a remote temporary file.';
      NERR_TooMuchData: result:= 'The data returned from a remote administration command has been truncated to 64K.';
      NERR_DeviceShareConflict: result:= 'This device cannot be shared as both a spooled and a non-spooled resource.';
      NERR_BrowserTableIncomplete: result:= 'The information in the list of servers may be incorrect.';
      NERR_NotLocalDomain: result:= 'The computer is not active in this domain.';
      NERR_IsDfsShare: result:= 'The share must be removed from the Distributed File System before it can be deleted.';
      NERR_DevInvalidOpCode: result:= 'The operation is invalid for this device.';
      NERR_DevNotFound: result:= 'This device cannot be shared.';
      NERR_DevNotOpen: result:= 'This device was not open.';
      NERR_BadQueueDevString: result:= 'This device name list is invalid.';
      NERR_BadQueuePriority: result:= 'The queue priority is invalid.';
      NERR_NoCommDevs: result:= 'There are no shared communication devices.';
      NERR_QueueNotFound: result:= 'The queue you specified does not exist.';
      NERR_BadDevString: result:= 'This list of devices is invalid.';
      NERR_BadDev: result:= 'The requested device is invalid.';
      NERR_InUseBySpooler: result:= 'This device is already in use by the spooler.';
      NERR_CommDevInUse: result:= 'This device is already in use as a communication device.';
      NERR_InvalidComputer: result:= 'This computer name is invalid.';
      NERR_MaxLenExceeded: result:= 'The string and prefix specified are too long.';
      NERR_BadComponent: result:= 'This path component is invalid.';
      NERR_CantType: result:= 'Could not determine the type of input.';
      NERR_TooManyEntries: result:= 'The buffer for types is not big enough.';
      NERR_ProfileFileTooBig: result:= 'Profile files cannot exceed 64K.';
      NERR_ProfileOffset: result:= 'The start offset is out of range.';
      NERR_ProfileCleanup: result:= 'The system cannot delete current connections to network resources.';
      NERR_ProfileUnknownCmd: result:= 'The system was unable to parse the command line in this file.';
      NERR_ProfileLoadErr: result:= 'An error occurred while loading the profile file.';
      NERR_ProfileSaveErr: result:= '@W Errors occurred while saving the profile file.  The profile was partially saved.';
      NERR_LogOverflow: result:= 'Log file %1 is full.';
      NERR_LogFileChanged: result:= 'This log file has changed between reads.';
      NERR_LogFileCorrupt: result:= 'Log file %1 is corrupt.';
      NERR_SourceIsDir: result:= 'The source path cannot be a directory.';
      NERR_BadSource: result:= 'The source path is illegal.';
      NERR_BadDest: result:= 'The destination path is illegal.';
      NERR_DifferentServers: result:= 'The source and destination paths are on different servers.';
      NERR_RunSrvPaused: result:= 'The Run server you requested is paused.';
      NERR_ErrCommRunSrv: result:= 'An error occurred when communicating with a Run server.';
      NERR_ErrorExecingGhost: result:= 'An error occurred when starting a background process.';
      NERR_ShareNotFound: result:= 'The shared resource you are connected to could not be found.';
      NERR_InvalidLana: result:= 'The LAN adapter number is invalid. ';
      NERR_OpenFiles: result:= 'There are open files on the connection.   ';
      NERR_ActiveConns: result:= 'Active connections still exist.';
      NERR_BadPasswordCore: result:= 'This share name or password is invalid.';
      NERR_DevInUse: result:= 'The device is being accessed by an active process.';
      NERR_LocalDrive: result:= 'The drive letter is in use locally.';
      NERR_AlertExists: result:= 'The specified client is already registered for the specified event.';
      NERR_TooManyAlerts: result:= 'The alert table is full.';
      NERR_NoSuchAlert: result:= 'An invalid or nonexistent alert name was raised.';
      NERR_BadRecipient: result:= 'The alert recipient is invalid.';
      NERR_AcctLimitExceeded: result:= 'A user'+chr($27)+'s session with this server has been deleted because the user'+chr($27)+'s logon hours are no longer valid.';
      NERR_InvalidLogSeek: result:= 'The log file does not contain the requested record number.';
      NERR_BadUasConfig: result:= 'The user accounts database is not configured correctly.';
      NERR_InvalidUASOp: result:= 'This operation is not permitted when the Netlogon service is running.';
      NERR_LastAdmin: result:= 'This operation is not allowed on the last administrative account.';
      NERR_DCNotFound: result:= 'Could not find domain controller for this domain.';
      NERR_LogonTrackingError: result:= 'Could not set logon information for this user.';
      NERR_NetlogonNotStarted: result:= 'The Netlogon service has not been started.';
      NERR_CanNotGrowUASFile: result:= 'Unable to add to the user accounts database.';
      NERR_TimeDiffAtDC: result:= 'This server'+chr($27)+'s clock is not synchronized with the primary domain controller'+chr($27)+'s clock.';
      NERR_PasswordMismatch: result:= 'A password mismatch has been detected.';
      NERR_NoSuchServer: result:= 'The server identification does not specify a valid server.';
      NERR_NoSuchSession: result:= 'The session identification does not specify a valid session.';
      NERR_NoSuchConnection: result:= 'The connection identification does not specify a valid connection.';
      NERR_TooManyServers: result:= 'There is no space for another entry in the table of available servers.';
      NERR_TooManySessions: result:= 'The server has reached the maximum number of sessions it supports.';
      NERR_TooManyConnections: result:= 'The server has reached the maximum number of connections it supports.';
      NERR_TooManyFiles: result:= 'The server cannot open more files because it has reached its maximum number.';
      NERR_NoAlternateServers: result:= 'There are no alternate servers registered on this server.';
      NERR_TryDownLevel: result:= 'Try down-level (remote admin protocol); version of API instead.';
      NERR_UPSDriverNotStarted: result:= 'The UPS driver could not be accessed by the UPS service.';
      NERR_UPSInvalidConfig: result:= 'The UPS service is not configured correctly.';
      NERR_UPSInvalidCommPort: result:= 'The UPS service could not access the specified Comm Port.';
      NERR_UPSSignalAsserted: result:= 'The UPS indicated a line fail or low battery situation. Service not started.';
      NERR_UPSShutdownFailed: result:= 'The UPS service failed to perform a system shut down.';
      NERR_BadDosRetCode: result:= 'The program below returned an MS-DOS error code:';
      NERR_ProgNeedsExtraMem: result:= 'The program below needs more memory:';
      NERR_BadDosFunction: result:= 'The program below called an unsupported MS-DOS function:';
      NERR_RemoteBootFailed: result:= 'The workstation failed to boot.';
      NERR_BadFileCheckSum: result:= 'The file below is corrupt.';
      NERR_NoRplBootSystem: result:= 'No loader is specified in the boot-block definition file.';
      NERR_RplLoadrNetBiosErr: result:= 'NetBIOS returned an error: The NCB and SMB are dumped above.';
      NERR_RplLoadrDiskErr: result:= 'A disk I/O error occurred.';
      NERR_ImageParamErr: result:= 'Image parameter substitution failed.';
      NERR_TooManyImageParams: result:= 'Too many image parameters cross disk sector boundaries.';
      NERR_NonDosFloppyUsed: result:= 'The image was not generated from an MS-DOS diskette formatted with /S.';
      NERR_RplBootRestart: result:= 'Remote boot will be restarted later.';
      NERR_RplSrvrCallFailed: result:= 'The call to the Remoteboot server failed.';
      NERR_CantConnectRplSrvr: result:= 'Cannot connect to the Remoteboot server.';
      NERR_CantOpenImageFile: result:= 'Cannot open image file on the Remoteboot server.';
      NERR_CallingRplSrvr: result:= 'Connecting to the Remoteboot server...';
      NERR_StartingRplBoot: result:= 'Connecting to the Remoteboot server...';
      NERR_RplBootServiceTerm: result:= 'Remote boot service was stopped; check the error log for the cause of the problem.';
      NERR_RplBootStartFailed: result:= 'Remote boot startup failed; check the error log for the cause of the problem.';
      NERR_RPL_CONNECTED: result:= 'A second connection to a Remoteboot resource is not allowed.';
      NERR_BrowserConfiguredToNotRun: result:= 'The browser service was configured with MaintainServerList=No.';
      NERR_RplNoAdaptersStarted: result:= 'Service failed to start since none of the network adapters started with this service.';
      NERR_RplBadRegistry: result:= 'Service failed to start due to bad startup information in the registry.';
      NERR_RplBadDatabase: result:= 'Service failed to start because its database is absent or corrupt.';
      NERR_RplRplfilesShare: result:= 'Service failed to start because RPLFILES share is absent.';
      NERR_RplNotRplServer: result:= 'Service failed to start because RPLUSER group is absent.';
      NERR_RplCannotEnum: result:= 'Cannot enumerate service records.';
      NERR_RplWkstaInfoCorrupted: result:= 'Workstation record information has been corrupted.';
      NERR_RplWkstaNotFound: result:= 'Workstation record was not found.';
      NERR_RplWkstaNameUnavailable: result:= 'Workstation name is in use by some other workstation.';
      NERR_RplProfileInfoCorrupted: result:= 'Profile record information has been corrupted.';
      NERR_RplProfileNotFound: result:= 'Profile record was not found.';
      NERR_RplProfileNameUnavailable: result:= 'Profile name is in use by some other profile.';
      NERR_RplProfileNotEmpty: result:= 'There are workstations using this profile.';
      NERR_RplConfigInfoCorrupted: result:= 'Configuration record information has been corrupted.';
      NERR_RplConfigNotFound: result:= 'Configuration record was not found.';
      NERR_RplAdapterInfoCorrupted: result:= 'Adapter id record information has been corrupted.';
      NERR_RplInternal: result:= 'An internal service error has occured.';
      NERR_RplVendorInfoCorrupted: result:= 'Vendor id record information has been corrupted.';
      NERR_RplBootInfoCorrupted: result:= 'Boot block record information has been corrupted.';
      NERR_RplWkstaNeedsUserAcct: result:= 'The user account for this workstation record is missing.';
      NERR_RplNeedsRPLUSERAcct: result:= 'The RPLUSER local group could not be found.';
      NERR_RplBootNotFound: result:= 'Boot block record was not found.';
      NERR_RplIncompatibleProfile: result:= 'Chosen profile is incompatible with this workstation.';
      NERR_RplAdapterNameUnavailable: result:= 'Chosen network adapter id is in use by some other workstation.';
      NERR_RplConfigNotEmpty: result:= 'There are profiles using this configuration.';
      NERR_RplBootInUse: result:= 'There are workstations, profiles or configurations using this boot block.';
      NERR_RplBackupDatabase: result:= 'Service failed to backup remoteboot database.';
      NERR_RplAdapterNotFound: result:= 'Adapter record was not found.';
      NERR_RplVendorNotFound: result:= 'Vendor record was not found.';
      NERR_RplVendorNameUnavailable: result:= 'Vendor name is in use by some other vendor record.';
      NERR_RplBootNameUnavailable: result:= '(boot name, vendor id); is in use by some other boot block record.';
      NERR_RplConfigNameUnavailable: result:= 'Configuration name is in use by some other configuration.';
      NERR_DfsInternalCorruption: result:= 'The internal database maintained by the Dfs service is corrupt';
      NERR_DfsVolumeDataCorrupt: result:= 'One of the records in the internal Dfs database is corrupt';
      NERR_DfsNoSuchVolume: result:= 'There is no volume whose entry path matches the input Entry Path';
      NERR_DfsVolumeAlreadyExists: result:= 'A volume with the given name already exists';
      NERR_DfsAlreadyShared: result:= 'The server share specified is already shared in the Dfs';
      NERR_DfsNoSuchShare: result:= 'The indicated server share does not support the indicated Dfs volume';
      NERR_DfsNotALeafVolume: result:= 'The operation is not valid on a non-leaf volume';
      NERR_DfsLeafVolume: result:= 'The operation is not valid on a leaf volume';
      NERR_DfsVolumeHasMultipleServers: result:= 'The operation is ambiguous because the volume has multiple servers';
      NERR_DfsCantCreateJunctionPoint: result:= 'Unable to create a junction point';
      NERR_DfsServerNotDfsAware: result:= 'The server is not Dfs Aware.';
      NERR_DfsBadRenamePath: result:= 'The specified rename target path is invalid.';
      NERR_DfsVolumeIsOffline: result:= 'The specified Dfs volume is offline.';
      NERR_DfsNoSuchServer: result:= 'The specified server is not a server for this volume.';
      NERR_DfsCyclicalName: result:= 'A cycle in the Dfs name was detected.';
      NERR_DfsNotSupportedInServerDfs: result:= 'The operation is not supported on a server-based Dfs.';
      NERR_DfsInternalError: result:= 'Dfs internal error.';
    else
      result:= 'Unknown network error ('+inttostr(lwNError)+').';
    end;
  end;

end.

